
import google.protobuf
from packaging.version import Version
if Version(google.protobuf.__version__).major >= 5:
  # -*- coding: utf-8 -*-
  # Generated by the protocol buffer compiler.  DO NOT EDIT!
  # source: databricks_tracing.proto
  # Protobuf Python Version: 5.26.0
  """Generated protocol buffer code."""
  from google.protobuf import descriptor as _descriptor
  from google.protobuf import descriptor_pool as _descriptor_pool
  from google.protobuf import symbol_database as _symbol_database
  from google.protobuf.internal import builder as _builder
  # @@protoc_insertion_point(imports)

  _sym_db = _symbol_database.Default()


  from . import assessments_pb2 as assessments__pb2
  from . import databricks_pb2 as databricks__pb2
  from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
  from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
  from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
  from opentelemetry.proto.trace.v1 import trace_pb2 as opentelemetry_dot_proto_dot_trace_dot_v1_dot_trace__pb2
  from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


  DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x64\x61tabricks_tracing.proto\x12\x11mlflow.databricks\x1a\x11\x61ssessments.proto\x1a\x10\x64\x61tabricks.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(opentelemetry/proto/trace/v1/trace.proto\x1a\x15scalapb/scalapb.proto\"z\n\x10UCSchemaLocation\x12\x14\n\x0c\x63\x61talog_name\x18\x01 \x01(\t\x12\x13\n\x0bschema_name\x18\x02 \x01(\t\x12\x1d\n\x15otel_spans_table_name\x18\x03 \x01(\t\x12\x1c\n\x14otel_logs_table_name\x18\x04 \x01(\t\"1\n\x18MlflowExperimentLocation\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"1\n\x16InferenceTableLocation\x12\x17\n\x0f\x66ull_table_name\x18\x01 \x01(\t\"\x9e\x03\n\rTraceLocation\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.mlflow.databricks.TraceLocation.TraceLocationType\x12H\n\x11mlflow_experiment\x18\x02 \x01(\x0b\x32+.mlflow.databricks.MlflowExperimentLocationH\x00\x12\x44\n\x0finference_table\x18\x03 \x01(\x0b\x32).mlflow.databricks.InferenceTableLocationH\x00\x12\x38\n\tuc_schema\x18\x04 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\"s\n\x11TraceLocationType\x12#\n\x1fTRACE_LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MLFLOW_EXPERIMENT\x10\x01\x12\x13\n\x0fINFERENCE_TABLE\x10\x02\x12\r\n\tUC_SCHEMA\x10\x03\x42\x0c\n\nidentifier\"\x9b\x05\n\tTraceInfo\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x19\n\x11\x63lient_request_id\x18\x02 \x01(\t\x12\x38\n\x0etrace_location\x18\x03 \x01(\x0b\x32 .mlflow.databricks.TraceLocation\x12\x17\n\x0frequest_preview\x18\x04 \x01(\t\x12\x18\n\x10response_preview\x18\x05 \x01(\t\x12\x30\n\x0crequest_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12\x65xecution_duration\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x05state\x18\x08 \x01(\x0e\x32\".mlflow.databricks.TraceInfo.State\x12G\n\x0etrace_metadata\x18\t \x03(\x0b\x32/.mlflow.databricks.TraceInfo.TraceMetadataEntry\x12\x32\n\x0b\x61ssessments\x18\n \x03(\x0b\x32\x1d.mlflow.databricks.Assessment\x12\x34\n\x04tags\x18\x0b \x03(\x0b\x32&.mlflow.databricks.TraceInfo.TagsEntry\x1a\x34\n\x12TraceMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\"\xcf\x01\n\x0f\x43reateTraceInfo\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x36\n\ntrace_info\x18\x02 \x01(\x0b\x32\x1c.mlflow.databricks.TraceInfoB\x04\xf8\x86\x19\x01\x1a<\n\x08Response\x12\x30\n\ntrace_info\x18\x01 \x01(\x0b\x32\x1c.mlflow.databricks.TraceInfo:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"c\n\tTracePath\x12>\n\x0etrace_location\x18\x01 \x01(\x0b\x32 .mlflow.databricks.TraceLocationB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\"l\n\x05Trace\x12\x30\n\ntrace_info\x18\x01 \x01(\x0b\x32\x1c.mlflow.databricks.TraceInfo\x12\x31\n\x05spans\x18\x02 \x03(\x0b\x32\".opentelemetry.proto.trace.v1.Span\"\xbb\x01\n\x0e\x42\x61tchGetTraces\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\ttrace_ids\x18\x02 \x03(\t\x12\x18\n\x10sql_warehouse_id\x18\x03 \x01(\t\x1a\x34\n\x08Response\x12(\n\x06traces\x18\x01 \x03(\x0b\x32\x18.mlflow.databricks.Trace:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xba\x01\n\x0cGetTraceInfo\x12\x16\n\x08trace_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08location\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x03 \x01(\t\x1a\x33\n\x08Response\x12\'\n\x05trace\x18\x01 \x01(\x0b\x32\x18.mlflow.databricks.Trace:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\x9b\x01\n\x0bSetTraceTag\x12\x16\n\x08trace_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x19\n\x0blocation_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\x03key\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\r\n\x05value\x18\x04 \x01(\t\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xa9\x01\n\x0e\x44\x65leteTraceTag\x12\x16\n\x08trace_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x19\n\x0blocation_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\x03key\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xb2\x02\n\x0cSearchTraces\x12\x33\n\tlocations\x18\x01 \x03(\x0b\x32 .mlflow.databricks.TraceLocation\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x18\n\x0bmax_results\x18\x03 \x01(\x05:\x03\x31\x30\x30\x12\x10\n\x08order_by\x18\x04 \x03(\t\x12\x18\n\x10sql_warehouse_id\x18\x05 \x01(\t\x12\x12\n\npage_token\x18\x06 \x01(\t\x1aV\n\x08Response\x12\x31\n\x0btrace_infos\x18\x01 \x03(\x0b\x32\x1c.mlflow.databricks.TraceInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xf5\x01\n\x1c\x43reateTraceUCStorageLocation\x12\x38\n\tuc_schema\x18\x01 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\x12\x1e\n\x10sql_warehouse_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x1a\x42\n\x08Response\x12\x36\n\tuc_schema\x18\x01 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocation:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]B\n\n\x08location\"\xbd\x01\n\x1fLinkExperimentToUCTraceLocation\x12\x1b\n\rexperiment_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x38\n\tuc_schema\x18\x02 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]B\n\n\x08location\"\xbf\x01\n!UnLinkExperimentToUCTraceLocation\x12\x1b\n\rexperiment_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x38\n\tuc_schema\x18\x02 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]B\n\n\x08location\"\xe0\x04\n\nAssessment\x12\x15\n\rassessment_id\x18\x01 \x01(\t\x12\x1d\n\x0f\x61ssessment_name\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x38\n\x0etrace_location\x18\x04 \x01(\x0b\x32 .mlflow.databricks.TraceLocation\x12\x0f\n\x07span_id\x18\x05 \x01(\t\x12\x34\n\x06source\x18\x06 \x01(\x0b\x32$.mlflow.assessments.AssessmentSource\x12/\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_update_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\t \x01(\x0b\x32\x1c.mlflow.assessments.FeedbackH\x00\x12\x36\n\x0b\x65xpectation\x18\n \x01(\x0b\x32\x1f.mlflow.assessments.ExpectationH\x00\x12\x11\n\trationale\x18\x0b \x01(\t\x12=\n\x08metadata\x18\x0c \x03(\x0b\x32+.mlflow.databricks.Assessment.MetadataEntry\x12\x11\n\toverrides\x18\r \x01(\t\x12\x13\n\x05valid\x18\x0e \x01(\x08:\x04true\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05value\"\xec\x01\n\x10\x43reateAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x37\n\nassessment\x18\x02 \x01(\x0b\x32\x1d.mlflow.databricks.AssessmentB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x03 \x01(\t\x1a=\n\x08Response\x12\x31\n\nassessment\x18\x01 \x01(\x0b\x32\x1d.mlflow.databricks.Assessment:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xe5\x01\n\rGetAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x1b\n\rassessment_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a=\n\x08Response\x12\x31\n\nassessment\x18\x01 \x01(\x0b\x32\x1d.mlflow.databricks.Assessment:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xa3\x02\n\x10UpdateAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x37\n\nassessment\x18\x02 \x01(\x0b\x32\x1d.mlflow.databricks.AssessmentB\x04\xf8\x86\x19\x01\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a=\n\x08Response\x12\x31\n\nassessment\x18\x01 \x01(\x0b\x32\x1d.mlflow.databricks.Assessment:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xb5\x01\n\x10\x44\x65leteAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x1b\n\rassessment_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\x92\x01\n\x13\x42\x61tchLinkTraceToRun\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\ttrace_ids\x18\x02 \x03(\t\x12\x14\n\x06run_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\x96\x01\n\x17\x42\x61tchUnlinkTraceFromRun\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\ttrace_ids\x18\x02 \x03(\t\x12\x14\n\x06run_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]2\xb0\x18\n\x19\x44\x61tabricksTrackingService\x12\xb8\x01\n\x0f\x63reateTraceInfo\x12\".mlflow.databricks.CreateTraceInfo\x1a\x1c.mlflow.databricks.TraceInfo\"c\xf2\x86\x19_\nE\n\x04POST\x12\x37/mlflow/traces/{location_id}/{trace_info.trace_id}/info\x1a\x04\x08\x04\x10\x00\x10\x03*\x14\x43reate Trace Info v4\x12\xaa\x01\n\x0e\x62\x61tchGetTraces\x12!.mlflow.databricks.BatchGetTraces\x1a*.mlflow.databricks.BatchGetTraces.Response\"I\xf2\x86\x19\x45\n2\n\x03GET\x12%/mlflow/traces/{location_id}/batchGet\x1a\x04\x08\x04\x10\x00\x10\x03*\rGet Traces V4\x12\xa8\x01\n\x0cgetTraceInfo\x12\x1f.mlflow.databricks.GetTraceInfo\x1a(.mlflow.databricks.GetTraceInfo.Response\"M\xf2\x86\x19I\n6\n\x03GET\x12)/mlflow/traces/{location}/{trace_id}/info\x1a\x04\x08\x04\x10\x00\x10\x03*\rGet TraceInfo\x12\xaa\x01\n\x0bsetTraceTag\x12\x1e.mlflow.databricks.SetTraceTag\x1a\'.mlflow.databricks.SetTraceTag.Response\"R\xf2\x86\x19N\n;\n\x05PATCH\x12,/mlflow/traces/{location_id}/{trace_id}/tags\x1a\x04\x08\x04\x10\x00\x10\x03*\rSet Trace Tag\x12\xbd\x01\n\x0e\x64\x65leteTraceTag\x12!.mlflow.databricks.DeleteTraceTag\x1a*.mlflow.databricks.DeleteTraceTag.Response\"\\\xf2\x86\x19X\nB\n\x06\x44\x45LETE\x12\x32/mlflow/traces/{location_id}/{trace_id}/tags/{key}\x1a\x04\x08\x04\x10\x00\x10\x03*\x10\x44\x65lete Trace Tag\x12\x95\x01\n\x0csearchTraces\x12\x1f.mlflow.databricks.SearchTraces\x1a(.mlflow.databricks.SearchTraces.Response\":\xf2\x86\x19\x36\n#\n\x04POST\x12\x15/mlflow/traces/search\x1a\x04\x08\x04\x10\x00\x10\x03*\rSearch Traces\x12\xda\x01\n\x1c\x63reateTraceUCStorageLocation\x12/.mlflow.databricks.CreateTraceUCStorageLocation\x1a\x38.mlflow.databricks.CreateTraceUCStorageLocation.Response\"O\xf2\x86\x19K\n%\n\x04POST\x12\x17/mlflow/traces/location\x1a\x04\x08\x04\x10\x00\x10\x03* Create Trace UC Storage Location\x12\xfc\x01\n\x1flinkExperimentToUCTraceLocation\x12\x32.mlflow.databricks.LinkExperimentToUCTraceLocation\x1a;.mlflow.databricks.LinkExperimentToUCTraceLocation.Response\"h\xf2\x86\x19\x64\n:\n\x04POST\x12,/mlflow/traces/{experiment_id}/link-location\x1a\x04\x08\x04\x10\x00\x10\x03*$Link Experiment to UC Trace Location\x12\x86\x02\n!unlinkExperimentToUCTraceLocation\x12\x34.mlflow.databricks.UnLinkExperimentToUCTraceLocation\x1a=.mlflow.databricks.UnLinkExperimentToUCTraceLocation.Response\"l\xf2\x86\x19h\n<\n\x04POST\x12./mlflow/traces/{experiment_id}/unlink-location\x1a\x04\x08\x04\x10\x00\x10\x03*&Unlink Experiment to UC Trace Location\x12\xce\x01\n\x10\x63reateAssessment\x12#.mlflow.databricks.CreateAssessment\x1a,.mlflow.databricks.CreateAssessment.Response\"g\xf2\x86\x19\x63\nL\n\x04POST\x12>/mlflow/traces/{location_id}/{assessment.trace_id}/assessments\x1a\x04\x08\x04\x10\x00\x10\x03*\x11\x43reate Assessment\x12\xc6\x01\n\rgetAssessment\x12 .mlflow.databricks.GetAssessment\x1a).mlflow.databricks.GetAssessment.Response\"h\xf2\x86\x19\x64\nP\n\x03GET\x12\x43/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\x1a\x04\x08\x04\x10\x00\x10\x03*\x0eGet Assessment\x12\xeb\x01\n\x10updateAssessment\x12#.mlflow.databricks.UpdateAssessment\x1a,.mlflow.databricks.UpdateAssessment.Response\"\x83\x01\xf2\x86\x19\x7f\nh\n\x05PATCH\x12Y/mlflow/traces/{location_id}/{assessment.trace_id}/assessments/{assessment.assessment_id}\x1a\x04\x08\x04\x10\x00\x10\x03*\x11Update Assessment\x12\xd5\x01\n\x10\x64\x65leteAssessment\x12#.mlflow.databricks.DeleteAssessment\x1a,.mlflow.databricks.DeleteAssessment.Response\"n\xf2\x86\x19j\nS\n\x06\x44\x45LETE\x12\x43/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\x1a\x04\x08\x04\x10\x00\x10\x03*\x11\x44\x65lete Assessment\x12\xce\x01\n\x13\x62\x61tchLinkTraceToRun\x12&.mlflow.databricks.BatchLinkTraceToRun\x1a/.mlflow.databricks.BatchLinkTraceToRun.Response\"^\xf2\x86\x19Z\nB\n\x04POST\x12\x34/mlflow/traces/{location_id}/link-to-run/batchCreate\x1a\x04\x08\x04\x10\x00\x10\x03*\x12Link Traces to Run\x12\xe4\x01\n\x17\x62\x61tchUnlinkTraceFromRun\x12*.mlflow.databricks.BatchUnlinkTraceFromRun\x1a\x33.mlflow.databricks.BatchUnlinkTraceFromRun.Response\"h\xf2\x86\x19\x64\nH\n\x06\x44\x45LETE\x12\x38/mlflow/traces/{location_id}/unlink-from-run/batchDelete\x1a\x04\x08\x04\x10\x00\x10\x03*\x16Unlink Traces from RunB\x03\x90\x01\x01')

  _globals = globals()
  _builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
  _builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'databricks_tracing_pb2', _globals)
  if not _descriptor._USE_C_DESCRIPTORS:
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\220\001\001'
    _globals['_TRACEINFO_TRACEMETADATAENTRY']._loaded_options = None
    _globals['_TRACEINFO_TRACEMETADATAENTRY']._serialized_options = b'8\001'
    _globals['_TRACEINFO_TAGSENTRY']._loaded_options = None
    _globals['_TRACEINFO_TAGSENTRY']._serialized_options = b'8\001'
    _globals['_CREATETRACEINFO'].fields_by_name['location_id']._loaded_options = None
    _globals['_CREATETRACEINFO'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_CREATETRACEINFO'].fields_by_name['trace_info']._loaded_options = None
    _globals['_CREATETRACEINFO'].fields_by_name['trace_info']._serialized_options = b'\370\206\031\001'
    _globals['_CREATETRACEINFO']._loaded_options = None
    _globals['_CREATETRACEINFO']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_TRACEPATH'].fields_by_name['trace_location']._loaded_options = None
    _globals['_TRACEPATH'].fields_by_name['trace_location']._serialized_options = b'\370\206\031\001'
    _globals['_TRACEPATH'].fields_by_name['trace_id']._loaded_options = None
    _globals['_TRACEPATH'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_BATCHGETTRACES'].fields_by_name['location_id']._loaded_options = None
    _globals['_BATCHGETTRACES'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_BATCHGETTRACES']._loaded_options = None
    _globals['_BATCHGETTRACES']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_GETTRACEINFO'].fields_by_name['trace_id']._loaded_options = None
    _globals['_GETTRACEINFO'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_GETTRACEINFO'].fields_by_name['location']._loaded_options = None
    _globals['_GETTRACEINFO'].fields_by_name['location']._serialized_options = b'\370\206\031\001'
    _globals['_GETTRACEINFO']._loaded_options = None
    _globals['_GETTRACEINFO']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_SETTRACETAG'].fields_by_name['trace_id']._loaded_options = None
    _globals['_SETTRACETAG'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_SETTRACETAG'].fields_by_name['location_id']._loaded_options = None
    _globals['_SETTRACETAG'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_SETTRACETAG'].fields_by_name['key']._loaded_options = None
    _globals['_SETTRACETAG'].fields_by_name['key']._serialized_options = b'\370\206\031\001'
    _globals['_SETTRACETAG']._loaded_options = None
    _globals['_SETTRACETAG']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_DELETETRACETAG'].fields_by_name['trace_id']._loaded_options = None
    _globals['_DELETETRACETAG'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_DELETETRACETAG'].fields_by_name['location_id']._loaded_options = None
    _globals['_DELETETRACETAG'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_DELETETRACETAG'].fields_by_name['key']._loaded_options = None
    _globals['_DELETETRACETAG'].fields_by_name['key']._serialized_options = b'\370\206\031\001'
    _globals['_DELETETRACETAG']._loaded_options = None
    _globals['_DELETETRACETAG']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_SEARCHTRACES']._loaded_options = None
    _globals['_SEARCHTRACES']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_CREATETRACEUCSTORAGELOCATION'].fields_by_name['sql_warehouse_id']._loaded_options = None
    _globals['_CREATETRACEUCSTORAGELOCATION'].fields_by_name['sql_warehouse_id']._serialized_options = b'\370\206\031\001'
    _globals['_CREATETRACEUCSTORAGELOCATION']._loaded_options = None
    _globals['_CREATETRACEUCSTORAGELOCATION']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION'].fields_by_name['experiment_id']._loaded_options = None
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION'].fields_by_name['experiment_id']._serialized_options = b'\370\206\031\001'
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION']._loaded_options = None
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION'].fields_by_name['experiment_id']._loaded_options = None
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION'].fields_by_name['experiment_id']._serialized_options = b'\370\206\031\001'
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION']._loaded_options = None
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_ASSESSMENT_METADATAENTRY']._loaded_options = None
    _globals['_ASSESSMENT_METADATAENTRY']._serialized_options = b'8\001'
    _globals['_ASSESSMENT'].fields_by_name['assessment_name']._loaded_options = None
    _globals['_ASSESSMENT'].fields_by_name['assessment_name']._serialized_options = b'\370\206\031\001'
    _globals['_ASSESSMENT'].fields_by_name['trace_id']._loaded_options = None
    _globals['_ASSESSMENT'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_CREATEASSESSMENT'].fields_by_name['location_id']._loaded_options = None
    _globals['_CREATEASSESSMENT'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_CREATEASSESSMENT'].fields_by_name['assessment']._loaded_options = None
    _globals['_CREATEASSESSMENT'].fields_by_name['assessment']._serialized_options = b'\370\206\031\001'
    _globals['_CREATEASSESSMENT']._loaded_options = None
    _globals['_CREATEASSESSMENT']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_GETASSESSMENT'].fields_by_name['location_id']._loaded_options = None
    _globals['_GETASSESSMENT'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_GETASSESSMENT'].fields_by_name['trace_id']._loaded_options = None
    _globals['_GETASSESSMENT'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_GETASSESSMENT'].fields_by_name['assessment_id']._loaded_options = None
    _globals['_GETASSESSMENT'].fields_by_name['assessment_id']._serialized_options = b'\370\206\031\001'
    _globals['_GETASSESSMENT']._loaded_options = None
    _globals['_GETASSESSMENT']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_UPDATEASSESSMENT'].fields_by_name['location_id']._loaded_options = None
    _globals['_UPDATEASSESSMENT'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_UPDATEASSESSMENT'].fields_by_name['assessment']._loaded_options = None
    _globals['_UPDATEASSESSMENT'].fields_by_name['assessment']._serialized_options = b'\370\206\031\001'
    _globals['_UPDATEASSESSMENT'].fields_by_name['update_mask']._loaded_options = None
    _globals['_UPDATEASSESSMENT'].fields_by_name['update_mask']._serialized_options = b'\370\206\031\001'
    _globals['_UPDATEASSESSMENT']._loaded_options = None
    _globals['_UPDATEASSESSMENT']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_DELETEASSESSMENT'].fields_by_name['location_id']._loaded_options = None
    _globals['_DELETEASSESSMENT'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_DELETEASSESSMENT'].fields_by_name['trace_id']._loaded_options = None
    _globals['_DELETEASSESSMENT'].fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _globals['_DELETEASSESSMENT'].fields_by_name['assessment_id']._loaded_options = None
    _globals['_DELETEASSESSMENT'].fields_by_name['assessment_id']._serialized_options = b'\370\206\031\001'
    _globals['_DELETEASSESSMENT']._loaded_options = None
    _globals['_DELETEASSESSMENT']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_BATCHLINKTRACETORUN'].fields_by_name['location_id']._loaded_options = None
    _globals['_BATCHLINKTRACETORUN'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_BATCHLINKTRACETORUN'].fields_by_name['run_id']._loaded_options = None
    _globals['_BATCHLINKTRACETORUN'].fields_by_name['run_id']._serialized_options = b'\370\206\031\001'
    _globals['_BATCHLINKTRACETORUN']._loaded_options = None
    _globals['_BATCHLINKTRACETORUN']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_BATCHUNLINKTRACEFROMRUN'].fields_by_name['location_id']._loaded_options = None
    _globals['_BATCHUNLINKTRACEFROMRUN'].fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _globals['_BATCHUNLINKTRACEFROMRUN'].fields_by_name['run_id']._loaded_options = None
    _globals['_BATCHUNLINKTRACEFROMRUN'].fields_by_name['run_id']._serialized_options = b'\370\206\031\001'
    _globals['_BATCHUNLINKTRACEFROMRUN']._loaded_options = None
    _globals['_BATCHUNLINKTRACEFROMRUN']._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['createTraceInfo']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['createTraceInfo']._serialized_options = b'\362\206\031_\nE\n\004POST\0227/mlflow/traces/{location_id}/{trace_info.trace_id}/info\032\004\010\004\020\000\020\003*\024Create Trace Info v4'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['batchGetTraces']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['batchGetTraces']._serialized_options = b'\362\206\031E\n2\n\003GET\022%/mlflow/traces/{location_id}/batchGet\032\004\010\004\020\000\020\003*\rGet Traces V4'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['getTraceInfo']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['getTraceInfo']._serialized_options = b'\362\206\031I\n6\n\003GET\022)/mlflow/traces/{location}/{trace_id}/info\032\004\010\004\020\000\020\003*\rGet TraceInfo'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['setTraceTag']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['setTraceTag']._serialized_options = b'\362\206\031N\n;\n\005PATCH\022,/mlflow/traces/{location_id}/{trace_id}/tags\032\004\010\004\020\000\020\003*\rSet Trace Tag'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['deleteTraceTag']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['deleteTraceTag']._serialized_options = b'\362\206\031X\nB\n\006DELETE\0222/mlflow/traces/{location_id}/{trace_id}/tags/{key}\032\004\010\004\020\000\020\003*\020Delete Trace Tag'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['searchTraces']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['searchTraces']._serialized_options = b'\362\206\0316\n#\n\004POST\022\025/mlflow/traces/search\032\004\010\004\020\000\020\003*\rSearch Traces'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['createTraceUCStorageLocation']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['createTraceUCStorageLocation']._serialized_options = b'\362\206\031K\n%\n\004POST\022\027/mlflow/traces/location\032\004\010\004\020\000\020\003* Create Trace UC Storage Location'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['linkExperimentToUCTraceLocation']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['linkExperimentToUCTraceLocation']._serialized_options = b'\362\206\031d\n:\n\004POST\022,/mlflow/traces/{experiment_id}/link-location\032\004\010\004\020\000\020\003*$Link Experiment to UC Trace Location'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['unlinkExperimentToUCTraceLocation']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['unlinkExperimentToUCTraceLocation']._serialized_options = b'\362\206\031h\n<\n\004POST\022./mlflow/traces/{experiment_id}/unlink-location\032\004\010\004\020\000\020\003*&Unlink Experiment to UC Trace Location'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['createAssessment']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['createAssessment']._serialized_options = b'\362\206\031c\nL\n\004POST\022>/mlflow/traces/{location_id}/{assessment.trace_id}/assessments\032\004\010\004\020\000\020\003*\021Create Assessment'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['getAssessment']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['getAssessment']._serialized_options = b'\362\206\031d\nP\n\003GET\022C/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\032\004\010\004\020\000\020\003*\016Get Assessment'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['updateAssessment']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['updateAssessment']._serialized_options = b'\362\206\031\177\nh\n\005PATCH\022Y/mlflow/traces/{location_id}/{assessment.trace_id}/assessments/{assessment.assessment_id}\032\004\010\004\020\000\020\003*\021Update Assessment'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['deleteAssessment']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['deleteAssessment']._serialized_options = b'\362\206\031j\nS\n\006DELETE\022C/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\032\004\010\004\020\000\020\003*\021Delete Assessment'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['batchLinkTraceToRun']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['batchLinkTraceToRun']._serialized_options = b'\362\206\031Z\nB\n\004POST\0224/mlflow/traces/{location_id}/link-to-run/batchCreate\032\004\010\004\020\000\020\003*\022Link Traces to Run'
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['batchUnlinkTraceFromRun']._loaded_options = None
    _globals['_DATABRICKSTRACKINGSERVICE'].methods_by_name['batchUnlinkTraceFromRun']._serialized_options = b'\362\206\031d\nH\n\006DELETE\0228/mlflow/traces/{location_id}/unlink-from-run/batchDelete\032\004\010\004\020\000\020\003*\026Unlink Traces from Run'
    _globals['_UCSCHEMALOCATION']._serialized_start=248
    _globals['_UCSCHEMALOCATION']._serialized_end=370
    _globals['_MLFLOWEXPERIMENTLOCATION']._serialized_start=372
    _globals['_MLFLOWEXPERIMENTLOCATION']._serialized_end=421
    _globals['_INFERENCETABLELOCATION']._serialized_start=423
    _globals['_INFERENCETABLELOCATION']._serialized_end=472
    _globals['_TRACELOCATION']._serialized_start=475
    _globals['_TRACELOCATION']._serialized_end=889
    _globals['_TRACELOCATION_TRACELOCATIONTYPE']._serialized_start=760
    _globals['_TRACELOCATION_TRACELOCATIONTYPE']._serialized_end=875
    _globals['_TRACEINFO']._serialized_start=892
    _globals['_TRACEINFO']._serialized_end=1559
    _globals['_TRACEINFO_TRACEMETADATAENTRY']._serialized_start=1394
    _globals['_TRACEINFO_TRACEMETADATAENTRY']._serialized_end=1446
    _globals['_TRACEINFO_TAGSENTRY']._serialized_start=1448
    _globals['_TRACEINFO_TAGSENTRY']._serialized_end=1491
    _globals['_TRACEINFO_STATE']._serialized_start=1493
    _globals['_TRACEINFO_STATE']._serialized_end=1559
    _globals['_CREATETRACEINFO']._serialized_start=1562
    _globals['_CREATETRACEINFO']._serialized_end=1769
    _globals['_CREATETRACEINFO_RESPONSE']._serialized_start=1664
    _globals['_CREATETRACEINFO_RESPONSE']._serialized_end=1724
    _globals['_TRACEPATH']._serialized_start=1771
    _globals['_TRACEPATH']._serialized_end=1870
    _globals['_TRACE']._serialized_start=1872
    _globals['_TRACE']._serialized_end=1980
    _globals['_BATCHGETTRACES']._serialized_start=1983
    _globals['_BATCHGETTRACES']._serialized_end=2170
    _globals['_BATCHGETTRACES_RESPONSE']._serialized_start=2073
    _globals['_BATCHGETTRACES_RESPONSE']._serialized_end=2125
    _globals['_GETTRACEINFO']._serialized_start=2173
    _globals['_GETTRACEINFO']._serialized_end=2359
    _globals['_GETTRACEINFO_RESPONSE']._serialized_start=2263
    _globals['_GETTRACEINFO_RESPONSE']._serialized_end=2314
    _globals['_SETTRACETAG']._serialized_start=2362
    _globals['_SETTRACETAG']._serialized_end=2517
    _globals['_SETTRACETAG_RESPONSE']._serialized_start=1664
    _globals['_SETTRACETAG_RESPONSE']._serialized_end=1674
    _globals['_DELETETRACETAG']._serialized_start=2520
    _globals['_DELETETRACETAG']._serialized_end=2689
    _globals['_DELETETRACETAG_RESPONSE']._serialized_start=1664
    _globals['_DELETETRACETAG_RESPONSE']._serialized_end=1674
    _globals['_SEARCHTRACES']._serialized_start=2692
    _globals['_SEARCHTRACES']._serialized_end=2998
    _globals['_SEARCHTRACES_RESPONSE']._serialized_start=2867
    _globals['_SEARCHTRACES_RESPONSE']._serialized_end=2953
    _globals['_CREATETRACEUCSTORAGELOCATION']._serialized_start=3001
    _globals['_CREATETRACEUCSTORAGELOCATION']._serialized_end=3246
    _globals['_CREATETRACEUCSTORAGELOCATION_RESPONSE']._serialized_start=3123
    _globals['_CREATETRACEUCSTORAGELOCATION_RESPONSE']._serialized_end=3189
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION']._serialized_start=3249
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION']._serialized_end=3438
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION_RESPONSE']._serialized_start=1664
    _globals['_LINKEXPERIMENTTOUCTRACELOCATION_RESPONSE']._serialized_end=1674
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION']._serialized_start=3441
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION']._serialized_end=3632
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION_RESPONSE']._serialized_start=1664
    _globals['_UNLINKEXPERIMENTTOUCTRACELOCATION_RESPONSE']._serialized_end=1674
    _globals['_ASSESSMENT']._serialized_start=3635
    _globals['_ASSESSMENT']._serialized_end=4243
    _globals['_ASSESSMENT_METADATAENTRY']._serialized_start=4187
    _globals['_ASSESSMENT_METADATAENTRY']._serialized_end=4234
    _globals['_CREATEASSESSMENT']._serialized_start=4246
    _globals['_CREATEASSESSMENT']._serialized_end=4482
    _globals['_CREATEASSESSMENT_RESPONSE']._serialized_start=4376
    _globals['_CREATEASSESSMENT_RESPONSE']._serialized_end=4437
    _globals['_GETASSESSMENT']._serialized_start=4485
    _globals['_GETASSESSMENT']._serialized_end=4714
    _globals['_GETASSESSMENT_RESPONSE']._serialized_start=4376
    _globals['_GETASSESSMENT_RESPONSE']._serialized_end=4437
    _globals['_UPDATEASSESSMENT']._serialized_start=4717
    _globals['_UPDATEASSESSMENT']._serialized_end=5008
    _globals['_UPDATEASSESSMENT_RESPONSE']._serialized_start=4376
    _globals['_UPDATEASSESSMENT_RESPONSE']._serialized_end=4437
    _globals['_DELETEASSESSMENT']._serialized_start=5011
    _globals['_DELETEASSESSMENT']._serialized_end=5192
    _globals['_DELETEASSESSMENT_RESPONSE']._serialized_start=1664
    _globals['_DELETEASSESSMENT_RESPONSE']._serialized_end=1674
    _globals['_BATCHLINKTRACETORUN']._serialized_start=5195
    _globals['_BATCHLINKTRACETORUN']._serialized_end=5341
    _globals['_BATCHLINKTRACETORUN_RESPONSE']._serialized_start=1664
    _globals['_BATCHLINKTRACETORUN_RESPONSE']._serialized_end=1674
    _globals['_BATCHUNLINKTRACEFROMRUN']._serialized_start=5344
    _globals['_BATCHUNLINKTRACEFROMRUN']._serialized_end=5494
    _globals['_BATCHUNLINKTRACEFROMRUN_RESPONSE']._serialized_start=1664
    _globals['_BATCHUNLINKTRACEFROMRUN_RESPONSE']._serialized_end=1674
    _globals['_DATABRICKSTRACKINGSERVICE']._serialized_start=5497
    _globals['_DATABRICKSTRACKINGSERVICE']._serialized_end=8617
  _builder.BuildServices(DESCRIPTOR, 'databricks_tracing_pb2', _globals)
  # @@protoc_insertion_point(module_scope)

else:
  # -*- coding: utf-8 -*-
  # Generated by the protocol buffer compiler.  DO NOT EDIT!
  # source: databricks_tracing.proto
  """Generated protocol buffer code."""
  from google.protobuf import descriptor as _descriptor
  from google.protobuf import descriptor_pool as _descriptor_pool
  from google.protobuf import message as _message
  from google.protobuf import reflection as _reflection
  from google.protobuf import symbol_database as _symbol_database
  from google.protobuf import service as _service
  from google.protobuf import service_reflection
  # @@protoc_insertion_point(imports)

  _sym_db = _symbol_database.Default()


  from . import assessments_pb2 as assessments__pb2
  from . import databricks_pb2 as databricks__pb2
  from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
  from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
  from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
  from opentelemetry.proto.trace.v1 import trace_pb2 as opentelemetry_dot_proto_dot_trace_dot_v1_dot_trace__pb2
  from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


  DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x64\x61tabricks_tracing.proto\x12\x11mlflow.databricks\x1a\x11\x61ssessments.proto\x1a\x10\x64\x61tabricks.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(opentelemetry/proto/trace/v1/trace.proto\x1a\x15scalapb/scalapb.proto\"z\n\x10UCSchemaLocation\x12\x14\n\x0c\x63\x61talog_name\x18\x01 \x01(\t\x12\x13\n\x0bschema_name\x18\x02 \x01(\t\x12\x1d\n\x15otel_spans_table_name\x18\x03 \x01(\t\x12\x1c\n\x14otel_logs_table_name\x18\x04 \x01(\t\"1\n\x18MlflowExperimentLocation\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"1\n\x16InferenceTableLocation\x12\x17\n\x0f\x66ull_table_name\x18\x01 \x01(\t\"\x9e\x03\n\rTraceLocation\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.mlflow.databricks.TraceLocation.TraceLocationType\x12H\n\x11mlflow_experiment\x18\x02 \x01(\x0b\x32+.mlflow.databricks.MlflowExperimentLocationH\x00\x12\x44\n\x0finference_table\x18\x03 \x01(\x0b\x32).mlflow.databricks.InferenceTableLocationH\x00\x12\x38\n\tuc_schema\x18\x04 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\"s\n\x11TraceLocationType\x12#\n\x1fTRACE_LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MLFLOW_EXPERIMENT\x10\x01\x12\x13\n\x0fINFERENCE_TABLE\x10\x02\x12\r\n\tUC_SCHEMA\x10\x03\x42\x0c\n\nidentifier\"\x9b\x05\n\tTraceInfo\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x19\n\x11\x63lient_request_id\x18\x02 \x01(\t\x12\x38\n\x0etrace_location\x18\x03 \x01(\x0b\x32 .mlflow.databricks.TraceLocation\x12\x17\n\x0frequest_preview\x18\x04 \x01(\t\x12\x18\n\x10response_preview\x18\x05 \x01(\t\x12\x30\n\x0crequest_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12\x65xecution_duration\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x05state\x18\x08 \x01(\x0e\x32\".mlflow.databricks.TraceInfo.State\x12G\n\x0etrace_metadata\x18\t \x03(\x0b\x32/.mlflow.databricks.TraceInfo.TraceMetadataEntry\x12\x32\n\x0b\x61ssessments\x18\n \x03(\x0b\x32\x1d.mlflow.databricks.Assessment\x12\x34\n\x04tags\x18\x0b \x03(\x0b\x32&.mlflow.databricks.TraceInfo.TagsEntry\x1a\x34\n\x12TraceMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\"\xcf\x01\n\x0f\x43reateTraceInfo\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x36\n\ntrace_info\x18\x02 \x01(\x0b\x32\x1c.mlflow.databricks.TraceInfoB\x04\xf8\x86\x19\x01\x1a<\n\x08Response\x12\x30\n\ntrace_info\x18\x01 \x01(\x0b\x32\x1c.mlflow.databricks.TraceInfo:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"c\n\tTracePath\x12>\n\x0etrace_location\x18\x01 \x01(\x0b\x32 .mlflow.databricks.TraceLocationB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\"l\n\x05Trace\x12\x30\n\ntrace_info\x18\x01 \x01(\x0b\x32\x1c.mlflow.databricks.TraceInfo\x12\x31\n\x05spans\x18\x02 \x03(\x0b\x32\".opentelemetry.proto.trace.v1.Span\"\xbb\x01\n\x0e\x42\x61tchGetTraces\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\ttrace_ids\x18\x02 \x03(\t\x12\x18\n\x10sql_warehouse_id\x18\x03 \x01(\t\x1a\x34\n\x08Response\x12(\n\x06traces\x18\x01 \x03(\x0b\x32\x18.mlflow.databricks.Trace:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xba\x01\n\x0cGetTraceInfo\x12\x16\n\x08trace_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08location\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x03 \x01(\t\x1a\x33\n\x08Response\x12\'\n\x05trace\x18\x01 \x01(\x0b\x32\x18.mlflow.databricks.Trace:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\x9b\x01\n\x0bSetTraceTag\x12\x16\n\x08trace_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x19\n\x0blocation_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\x03key\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\r\n\x05value\x18\x04 \x01(\t\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xa9\x01\n\x0e\x44\x65leteTraceTag\x12\x16\n\x08trace_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x19\n\x0blocation_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\x03key\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xb2\x02\n\x0cSearchTraces\x12\x33\n\tlocations\x18\x01 \x03(\x0b\x32 .mlflow.databricks.TraceLocation\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x18\n\x0bmax_results\x18\x03 \x01(\x05:\x03\x31\x30\x30\x12\x10\n\x08order_by\x18\x04 \x03(\t\x12\x18\n\x10sql_warehouse_id\x18\x05 \x01(\t\x12\x12\n\npage_token\x18\x06 \x01(\t\x1aV\n\x08Response\x12\x31\n\x0btrace_infos\x18\x01 \x03(\x0b\x32\x1c.mlflow.databricks.TraceInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xf5\x01\n\x1c\x43reateTraceUCStorageLocation\x12\x38\n\tuc_schema\x18\x01 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\x12\x1e\n\x10sql_warehouse_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x1a\x42\n\x08Response\x12\x36\n\tuc_schema\x18\x01 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocation:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]B\n\n\x08location\"\xbd\x01\n\x1fLinkExperimentToUCTraceLocation\x12\x1b\n\rexperiment_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x38\n\tuc_schema\x18\x02 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]B\n\n\x08location\"\xbf\x01\n!UnLinkExperimentToUCTraceLocation\x12\x1b\n\rexperiment_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x38\n\tuc_schema\x18\x02 \x01(\x0b\x32#.mlflow.databricks.UCSchemaLocationH\x00\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]B\n\n\x08location\"\xe0\x04\n\nAssessment\x12\x15\n\rassessment_id\x18\x01 \x01(\t\x12\x1d\n\x0f\x61ssessment_name\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x38\n\x0etrace_location\x18\x04 \x01(\x0b\x32 .mlflow.databricks.TraceLocation\x12\x0f\n\x07span_id\x18\x05 \x01(\t\x12\x34\n\x06source\x18\x06 \x01(\x0b\x32$.mlflow.assessments.AssessmentSource\x12/\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_update_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\t \x01(\x0b\x32\x1c.mlflow.assessments.FeedbackH\x00\x12\x36\n\x0b\x65xpectation\x18\n \x01(\x0b\x32\x1f.mlflow.assessments.ExpectationH\x00\x12\x11\n\trationale\x18\x0b \x01(\t\x12=\n\x08metadata\x18\x0c \x03(\x0b\x32+.mlflow.databricks.Assessment.MetadataEntry\x12\x11\n\toverrides\x18\r \x01(\t\x12\x13\n\x05valid\x18\x0e \x01(\x08:\x04true\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05value\"\xec\x01\n\x10\x43reateAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x37\n\nassessment\x18\x02 \x01(\x0b\x32\x1d.mlflow.databricks.AssessmentB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x03 \x01(\t\x1a=\n\x08Response\x12\x31\n\nassessment\x18\x01 \x01(\x0b\x32\x1d.mlflow.databricks.Assessment:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xe5\x01\n\rGetAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x1b\n\rassessment_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a=\n\x08Response\x12\x31\n\nassessment\x18\x01 \x01(\x0b\x32\x1d.mlflow.databricks.Assessment:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xa3\x02\n\x10UpdateAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x37\n\nassessment\x18\x02 \x01(\x0b\x32\x1d.mlflow.databricks.AssessmentB\x04\xf8\x86\x19\x01\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a=\n\x08Response\x12\x31\n\nassessment\x18\x01 \x01(\x0b\x32\x1d.mlflow.databricks.Assessment:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\xb5\x01\n\x10\x44\x65leteAssessment\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x16\n\x08trace_id\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x1b\n\rassessment_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x12\x18\n\x10sql_warehouse_id\x18\x04 \x01(\t\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\x92\x01\n\x13\x42\x61tchLinkTraceToRun\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\ttrace_ids\x18\x02 \x03(\t\x12\x14\n\x06run_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]\"\x96\x01\n\x17\x42\x61tchUnlinkTraceFromRun\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x11\n\ttrace_ids\x18\x02 \x03(\t\x12\x14\n\x06run_id\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01\x1a\n\n\x08Response:+\xe2?(\n&com.databricks.rpc.RPC[$this.Response]2\xb0\x18\n\x19\x44\x61tabricksTrackingService\x12\xb8\x01\n\x0f\x63reateTraceInfo\x12\".mlflow.databricks.CreateTraceInfo\x1a\x1c.mlflow.databricks.TraceInfo\"c\xf2\x86\x19_\nE\n\x04POST\x12\x37/mlflow/traces/{location_id}/{trace_info.trace_id}/info\x1a\x04\x08\x04\x10\x00\x10\x03*\x14\x43reate Trace Info v4\x12\xaa\x01\n\x0e\x62\x61tchGetTraces\x12!.mlflow.databricks.BatchGetTraces\x1a*.mlflow.databricks.BatchGetTraces.Response\"I\xf2\x86\x19\x45\n2\n\x03GET\x12%/mlflow/traces/{location_id}/batchGet\x1a\x04\x08\x04\x10\x00\x10\x03*\rGet Traces V4\x12\xa8\x01\n\x0cgetTraceInfo\x12\x1f.mlflow.databricks.GetTraceInfo\x1a(.mlflow.databricks.GetTraceInfo.Response\"M\xf2\x86\x19I\n6\n\x03GET\x12)/mlflow/traces/{location}/{trace_id}/info\x1a\x04\x08\x04\x10\x00\x10\x03*\rGet TraceInfo\x12\xaa\x01\n\x0bsetTraceTag\x12\x1e.mlflow.databricks.SetTraceTag\x1a\'.mlflow.databricks.SetTraceTag.Response\"R\xf2\x86\x19N\n;\n\x05PATCH\x12,/mlflow/traces/{location_id}/{trace_id}/tags\x1a\x04\x08\x04\x10\x00\x10\x03*\rSet Trace Tag\x12\xbd\x01\n\x0e\x64\x65leteTraceTag\x12!.mlflow.databricks.DeleteTraceTag\x1a*.mlflow.databricks.DeleteTraceTag.Response\"\\\xf2\x86\x19X\nB\n\x06\x44\x45LETE\x12\x32/mlflow/traces/{location_id}/{trace_id}/tags/{key}\x1a\x04\x08\x04\x10\x00\x10\x03*\x10\x44\x65lete Trace Tag\x12\x95\x01\n\x0csearchTraces\x12\x1f.mlflow.databricks.SearchTraces\x1a(.mlflow.databricks.SearchTraces.Response\":\xf2\x86\x19\x36\n#\n\x04POST\x12\x15/mlflow/traces/search\x1a\x04\x08\x04\x10\x00\x10\x03*\rSearch Traces\x12\xda\x01\n\x1c\x63reateTraceUCStorageLocation\x12/.mlflow.databricks.CreateTraceUCStorageLocation\x1a\x38.mlflow.databricks.CreateTraceUCStorageLocation.Response\"O\xf2\x86\x19K\n%\n\x04POST\x12\x17/mlflow/traces/location\x1a\x04\x08\x04\x10\x00\x10\x03* Create Trace UC Storage Location\x12\xfc\x01\n\x1flinkExperimentToUCTraceLocation\x12\x32.mlflow.databricks.LinkExperimentToUCTraceLocation\x1a;.mlflow.databricks.LinkExperimentToUCTraceLocation.Response\"h\xf2\x86\x19\x64\n:\n\x04POST\x12,/mlflow/traces/{experiment_id}/link-location\x1a\x04\x08\x04\x10\x00\x10\x03*$Link Experiment to UC Trace Location\x12\x86\x02\n!unlinkExperimentToUCTraceLocation\x12\x34.mlflow.databricks.UnLinkExperimentToUCTraceLocation\x1a=.mlflow.databricks.UnLinkExperimentToUCTraceLocation.Response\"l\xf2\x86\x19h\n<\n\x04POST\x12./mlflow/traces/{experiment_id}/unlink-location\x1a\x04\x08\x04\x10\x00\x10\x03*&Unlink Experiment to UC Trace Location\x12\xce\x01\n\x10\x63reateAssessment\x12#.mlflow.databricks.CreateAssessment\x1a,.mlflow.databricks.CreateAssessment.Response\"g\xf2\x86\x19\x63\nL\n\x04POST\x12>/mlflow/traces/{location_id}/{assessment.trace_id}/assessments\x1a\x04\x08\x04\x10\x00\x10\x03*\x11\x43reate Assessment\x12\xc6\x01\n\rgetAssessment\x12 .mlflow.databricks.GetAssessment\x1a).mlflow.databricks.GetAssessment.Response\"h\xf2\x86\x19\x64\nP\n\x03GET\x12\x43/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\x1a\x04\x08\x04\x10\x00\x10\x03*\x0eGet Assessment\x12\xeb\x01\n\x10updateAssessment\x12#.mlflow.databricks.UpdateAssessment\x1a,.mlflow.databricks.UpdateAssessment.Response\"\x83\x01\xf2\x86\x19\x7f\nh\n\x05PATCH\x12Y/mlflow/traces/{location_id}/{assessment.trace_id}/assessments/{assessment.assessment_id}\x1a\x04\x08\x04\x10\x00\x10\x03*\x11Update Assessment\x12\xd5\x01\n\x10\x64\x65leteAssessment\x12#.mlflow.databricks.DeleteAssessment\x1a,.mlflow.databricks.DeleteAssessment.Response\"n\xf2\x86\x19j\nS\n\x06\x44\x45LETE\x12\x43/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\x1a\x04\x08\x04\x10\x00\x10\x03*\x11\x44\x65lete Assessment\x12\xce\x01\n\x13\x62\x61tchLinkTraceToRun\x12&.mlflow.databricks.BatchLinkTraceToRun\x1a/.mlflow.databricks.BatchLinkTraceToRun.Response\"^\xf2\x86\x19Z\nB\n\x04POST\x12\x34/mlflow/traces/{location_id}/link-to-run/batchCreate\x1a\x04\x08\x04\x10\x00\x10\x03*\x12Link Traces to Run\x12\xe4\x01\n\x17\x62\x61tchUnlinkTraceFromRun\x12*.mlflow.databricks.BatchUnlinkTraceFromRun\x1a\x33.mlflow.databricks.BatchUnlinkTraceFromRun.Response\"h\xf2\x86\x19\x64\nH\n\x06\x44\x45LETE\x12\x38/mlflow/traces/{location_id}/unlink-from-run/batchDelete\x1a\x04\x08\x04\x10\x00\x10\x03*\x16Unlink Traces from RunB\x03\x90\x01\x01')



  _UCSCHEMALOCATION = DESCRIPTOR.message_types_by_name['UCSchemaLocation']
  _MLFLOWEXPERIMENTLOCATION = DESCRIPTOR.message_types_by_name['MlflowExperimentLocation']
  _INFERENCETABLELOCATION = DESCRIPTOR.message_types_by_name['InferenceTableLocation']
  _TRACELOCATION = DESCRIPTOR.message_types_by_name['TraceLocation']
  _TRACEINFO = DESCRIPTOR.message_types_by_name['TraceInfo']
  _TRACEINFO_TRACEMETADATAENTRY = _TRACEINFO.nested_types_by_name['TraceMetadataEntry']
  _TRACEINFO_TAGSENTRY = _TRACEINFO.nested_types_by_name['TagsEntry']
  _CREATETRACEINFO = DESCRIPTOR.message_types_by_name['CreateTraceInfo']
  _CREATETRACEINFO_RESPONSE = _CREATETRACEINFO.nested_types_by_name['Response']
  _TRACEPATH = DESCRIPTOR.message_types_by_name['TracePath']
  _TRACE = DESCRIPTOR.message_types_by_name['Trace']
  _BATCHGETTRACES = DESCRIPTOR.message_types_by_name['BatchGetTraces']
  _BATCHGETTRACES_RESPONSE = _BATCHGETTRACES.nested_types_by_name['Response']
  _GETTRACEINFO = DESCRIPTOR.message_types_by_name['GetTraceInfo']
  _GETTRACEINFO_RESPONSE = _GETTRACEINFO.nested_types_by_name['Response']
  _SETTRACETAG = DESCRIPTOR.message_types_by_name['SetTraceTag']
  _SETTRACETAG_RESPONSE = _SETTRACETAG.nested_types_by_name['Response']
  _DELETETRACETAG = DESCRIPTOR.message_types_by_name['DeleteTraceTag']
  _DELETETRACETAG_RESPONSE = _DELETETRACETAG.nested_types_by_name['Response']
  _SEARCHTRACES = DESCRIPTOR.message_types_by_name['SearchTraces']
  _SEARCHTRACES_RESPONSE = _SEARCHTRACES.nested_types_by_name['Response']
  _CREATETRACEUCSTORAGELOCATION = DESCRIPTOR.message_types_by_name['CreateTraceUCStorageLocation']
  _CREATETRACEUCSTORAGELOCATION_RESPONSE = _CREATETRACEUCSTORAGELOCATION.nested_types_by_name['Response']
  _LINKEXPERIMENTTOUCTRACELOCATION = DESCRIPTOR.message_types_by_name['LinkExperimentToUCTraceLocation']
  _LINKEXPERIMENTTOUCTRACELOCATION_RESPONSE = _LINKEXPERIMENTTOUCTRACELOCATION.nested_types_by_name['Response']
  _UNLINKEXPERIMENTTOUCTRACELOCATION = DESCRIPTOR.message_types_by_name['UnLinkExperimentToUCTraceLocation']
  _UNLINKEXPERIMENTTOUCTRACELOCATION_RESPONSE = _UNLINKEXPERIMENTTOUCTRACELOCATION.nested_types_by_name['Response']
  _ASSESSMENT = DESCRIPTOR.message_types_by_name['Assessment']
  _ASSESSMENT_METADATAENTRY = _ASSESSMENT.nested_types_by_name['MetadataEntry']
  _CREATEASSESSMENT = DESCRIPTOR.message_types_by_name['CreateAssessment']
  _CREATEASSESSMENT_RESPONSE = _CREATEASSESSMENT.nested_types_by_name['Response']
  _GETASSESSMENT = DESCRIPTOR.message_types_by_name['GetAssessment']
  _GETASSESSMENT_RESPONSE = _GETASSESSMENT.nested_types_by_name['Response']
  _UPDATEASSESSMENT = DESCRIPTOR.message_types_by_name['UpdateAssessment']
  _UPDATEASSESSMENT_RESPONSE = _UPDATEASSESSMENT.nested_types_by_name['Response']
  _DELETEASSESSMENT = DESCRIPTOR.message_types_by_name['DeleteAssessment']
  _DELETEASSESSMENT_RESPONSE = _DELETEASSESSMENT.nested_types_by_name['Response']
  _BATCHLINKTRACETORUN = DESCRIPTOR.message_types_by_name['BatchLinkTraceToRun']
  _BATCHLINKTRACETORUN_RESPONSE = _BATCHLINKTRACETORUN.nested_types_by_name['Response']
  _BATCHUNLINKTRACEFROMRUN = DESCRIPTOR.message_types_by_name['BatchUnlinkTraceFromRun']
  _BATCHUNLINKTRACEFROMRUN_RESPONSE = _BATCHUNLINKTRACEFROMRUN.nested_types_by_name['Response']
  _TRACELOCATION_TRACELOCATIONTYPE = _TRACELOCATION.enum_types_by_name['TraceLocationType']
  _TRACEINFO_STATE = _TRACEINFO.enum_types_by_name['State']
  UCSchemaLocation = _reflection.GeneratedProtocolMessageType('UCSchemaLocation', (_message.Message,), {
    'DESCRIPTOR' : _UCSCHEMALOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.UCSchemaLocation)
    })
  _sym_db.RegisterMessage(UCSchemaLocation)

  MlflowExperimentLocation = _reflection.GeneratedProtocolMessageType('MlflowExperimentLocation', (_message.Message,), {
    'DESCRIPTOR' : _MLFLOWEXPERIMENTLOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.MlflowExperimentLocation)
    })
  _sym_db.RegisterMessage(MlflowExperimentLocation)

  InferenceTableLocation = _reflection.GeneratedProtocolMessageType('InferenceTableLocation', (_message.Message,), {
    'DESCRIPTOR' : _INFERENCETABLELOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.InferenceTableLocation)
    })
  _sym_db.RegisterMessage(InferenceTableLocation)

  TraceLocation = _reflection.GeneratedProtocolMessageType('TraceLocation', (_message.Message,), {
    'DESCRIPTOR' : _TRACELOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.TraceLocation)
    })
  _sym_db.RegisterMessage(TraceLocation)

  TraceInfo = _reflection.GeneratedProtocolMessageType('TraceInfo', (_message.Message,), {

    'TraceMetadataEntry' : _reflection.GeneratedProtocolMessageType('TraceMetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _TRACEINFO_TRACEMETADATAENTRY,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.TraceInfo.TraceMetadataEntry)
      })
    ,

    'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
      'DESCRIPTOR' : _TRACEINFO_TAGSENTRY,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.TraceInfo.TagsEntry)
      })
    ,
    'DESCRIPTOR' : _TRACEINFO,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.TraceInfo)
    })
  _sym_db.RegisterMessage(TraceInfo)
  _sym_db.RegisterMessage(TraceInfo.TraceMetadataEntry)
  _sym_db.RegisterMessage(TraceInfo.TagsEntry)

  CreateTraceInfo = _reflection.GeneratedProtocolMessageType('CreateTraceInfo', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _CREATETRACEINFO_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.CreateTraceInfo.Response)
      })
    ,
    'DESCRIPTOR' : _CREATETRACEINFO,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.CreateTraceInfo)
    })
  _sym_db.RegisterMessage(CreateTraceInfo)
  _sym_db.RegisterMessage(CreateTraceInfo.Response)

  TracePath = _reflection.GeneratedProtocolMessageType('TracePath', (_message.Message,), {
    'DESCRIPTOR' : _TRACEPATH,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.TracePath)
    })
  _sym_db.RegisterMessage(TracePath)

  Trace = _reflection.GeneratedProtocolMessageType('Trace', (_message.Message,), {
    'DESCRIPTOR' : _TRACE,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.Trace)
    })
  _sym_db.RegisterMessage(Trace)

  BatchGetTraces = _reflection.GeneratedProtocolMessageType('BatchGetTraces', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _BATCHGETTRACES_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.BatchGetTraces.Response)
      })
    ,
    'DESCRIPTOR' : _BATCHGETTRACES,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.BatchGetTraces)
    })
  _sym_db.RegisterMessage(BatchGetTraces)
  _sym_db.RegisterMessage(BatchGetTraces.Response)

  GetTraceInfo = _reflection.GeneratedProtocolMessageType('GetTraceInfo', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _GETTRACEINFO_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.GetTraceInfo.Response)
      })
    ,
    'DESCRIPTOR' : _GETTRACEINFO,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.GetTraceInfo)
    })
  _sym_db.RegisterMessage(GetTraceInfo)
  _sym_db.RegisterMessage(GetTraceInfo.Response)

  SetTraceTag = _reflection.GeneratedProtocolMessageType('SetTraceTag', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _SETTRACETAG_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.SetTraceTag.Response)
      })
    ,
    'DESCRIPTOR' : _SETTRACETAG,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.SetTraceTag)
    })
  _sym_db.RegisterMessage(SetTraceTag)
  _sym_db.RegisterMessage(SetTraceTag.Response)

  DeleteTraceTag = _reflection.GeneratedProtocolMessageType('DeleteTraceTag', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _DELETETRACETAG_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.DeleteTraceTag.Response)
      })
    ,
    'DESCRIPTOR' : _DELETETRACETAG,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.DeleteTraceTag)
    })
  _sym_db.RegisterMessage(DeleteTraceTag)
  _sym_db.RegisterMessage(DeleteTraceTag.Response)

  SearchTraces = _reflection.GeneratedProtocolMessageType('SearchTraces', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _SEARCHTRACES_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.SearchTraces.Response)
      })
    ,
    'DESCRIPTOR' : _SEARCHTRACES,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.SearchTraces)
    })
  _sym_db.RegisterMessage(SearchTraces)
  _sym_db.RegisterMessage(SearchTraces.Response)

  CreateTraceUCStorageLocation = _reflection.GeneratedProtocolMessageType('CreateTraceUCStorageLocation', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _CREATETRACEUCSTORAGELOCATION_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.CreateTraceUCStorageLocation.Response)
      })
    ,
    'DESCRIPTOR' : _CREATETRACEUCSTORAGELOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.CreateTraceUCStorageLocation)
    })
  _sym_db.RegisterMessage(CreateTraceUCStorageLocation)
  _sym_db.RegisterMessage(CreateTraceUCStorageLocation.Response)

  LinkExperimentToUCTraceLocation = _reflection.GeneratedProtocolMessageType('LinkExperimentToUCTraceLocation', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _LINKEXPERIMENTTOUCTRACELOCATION_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.LinkExperimentToUCTraceLocation.Response)
      })
    ,
    'DESCRIPTOR' : _LINKEXPERIMENTTOUCTRACELOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.LinkExperimentToUCTraceLocation)
    })
  _sym_db.RegisterMessage(LinkExperimentToUCTraceLocation)
  _sym_db.RegisterMessage(LinkExperimentToUCTraceLocation.Response)

  UnLinkExperimentToUCTraceLocation = _reflection.GeneratedProtocolMessageType('UnLinkExperimentToUCTraceLocation', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _UNLINKEXPERIMENTTOUCTRACELOCATION_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.UnLinkExperimentToUCTraceLocation.Response)
      })
    ,
    'DESCRIPTOR' : _UNLINKEXPERIMENTTOUCTRACELOCATION,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.UnLinkExperimentToUCTraceLocation)
    })
  _sym_db.RegisterMessage(UnLinkExperimentToUCTraceLocation)
  _sym_db.RegisterMessage(UnLinkExperimentToUCTraceLocation.Response)

  Assessment = _reflection.GeneratedProtocolMessageType('Assessment', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _ASSESSMENT_METADATAENTRY,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.Assessment.MetadataEntry)
      })
    ,
    'DESCRIPTOR' : _ASSESSMENT,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.Assessment)
    })
  _sym_db.RegisterMessage(Assessment)
  _sym_db.RegisterMessage(Assessment.MetadataEntry)

  CreateAssessment = _reflection.GeneratedProtocolMessageType('CreateAssessment', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _CREATEASSESSMENT_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.CreateAssessment.Response)
      })
    ,
    'DESCRIPTOR' : _CREATEASSESSMENT,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.CreateAssessment)
    })
  _sym_db.RegisterMessage(CreateAssessment)
  _sym_db.RegisterMessage(CreateAssessment.Response)

  GetAssessment = _reflection.GeneratedProtocolMessageType('GetAssessment', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _GETASSESSMENT_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.GetAssessment.Response)
      })
    ,
    'DESCRIPTOR' : _GETASSESSMENT,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.GetAssessment)
    })
  _sym_db.RegisterMessage(GetAssessment)
  _sym_db.RegisterMessage(GetAssessment.Response)

  UpdateAssessment = _reflection.GeneratedProtocolMessageType('UpdateAssessment', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _UPDATEASSESSMENT_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.UpdateAssessment.Response)
      })
    ,
    'DESCRIPTOR' : _UPDATEASSESSMENT,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.UpdateAssessment)
    })
  _sym_db.RegisterMessage(UpdateAssessment)
  _sym_db.RegisterMessage(UpdateAssessment.Response)

  DeleteAssessment = _reflection.GeneratedProtocolMessageType('DeleteAssessment', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _DELETEASSESSMENT_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.DeleteAssessment.Response)
      })
    ,
    'DESCRIPTOR' : _DELETEASSESSMENT,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.DeleteAssessment)
    })
  _sym_db.RegisterMessage(DeleteAssessment)
  _sym_db.RegisterMessage(DeleteAssessment.Response)

  BatchLinkTraceToRun = _reflection.GeneratedProtocolMessageType('BatchLinkTraceToRun', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _BATCHLINKTRACETORUN_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.BatchLinkTraceToRun.Response)
      })
    ,
    'DESCRIPTOR' : _BATCHLINKTRACETORUN,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.BatchLinkTraceToRun)
    })
  _sym_db.RegisterMessage(BatchLinkTraceToRun)
  _sym_db.RegisterMessage(BatchLinkTraceToRun.Response)

  BatchUnlinkTraceFromRun = _reflection.GeneratedProtocolMessageType('BatchUnlinkTraceFromRun', (_message.Message,), {

    'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
      'DESCRIPTOR' : _BATCHUNLINKTRACEFROMRUN_RESPONSE,
      '__module__' : 'databricks_tracing_pb2'
      # @@protoc_insertion_point(class_scope:mlflow.databricks.BatchUnlinkTraceFromRun.Response)
      })
    ,
    'DESCRIPTOR' : _BATCHUNLINKTRACEFROMRUN,
    '__module__' : 'databricks_tracing_pb2'
    # @@protoc_insertion_point(class_scope:mlflow.databricks.BatchUnlinkTraceFromRun)
    })
  _sym_db.RegisterMessage(BatchUnlinkTraceFromRun)
  _sym_db.RegisterMessage(BatchUnlinkTraceFromRun.Response)

  _DATABRICKSTRACKINGSERVICE = DESCRIPTOR.services_by_name['DatabricksTrackingService']
  if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\220\001\001'
    _TRACEINFO_TRACEMETADATAENTRY._options = None
    _TRACEINFO_TRACEMETADATAENTRY._serialized_options = b'8\001'
    _TRACEINFO_TAGSENTRY._options = None
    _TRACEINFO_TAGSENTRY._serialized_options = b'8\001'
    _CREATETRACEINFO.fields_by_name['location_id']._options = None
    _CREATETRACEINFO.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _CREATETRACEINFO.fields_by_name['trace_info']._options = None
    _CREATETRACEINFO.fields_by_name['trace_info']._serialized_options = b'\370\206\031\001'
    _CREATETRACEINFO._options = None
    _CREATETRACEINFO._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _TRACEPATH.fields_by_name['trace_location']._options = None
    _TRACEPATH.fields_by_name['trace_location']._serialized_options = b'\370\206\031\001'
    _TRACEPATH.fields_by_name['trace_id']._options = None
    _TRACEPATH.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _BATCHGETTRACES.fields_by_name['location_id']._options = None
    _BATCHGETTRACES.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _BATCHGETTRACES._options = None
    _BATCHGETTRACES._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _GETTRACEINFO.fields_by_name['trace_id']._options = None
    _GETTRACEINFO.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _GETTRACEINFO.fields_by_name['location']._options = None
    _GETTRACEINFO.fields_by_name['location']._serialized_options = b'\370\206\031\001'
    _GETTRACEINFO._options = None
    _GETTRACEINFO._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _SETTRACETAG.fields_by_name['trace_id']._options = None
    _SETTRACETAG.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _SETTRACETAG.fields_by_name['location_id']._options = None
    _SETTRACETAG.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _SETTRACETAG.fields_by_name['key']._options = None
    _SETTRACETAG.fields_by_name['key']._serialized_options = b'\370\206\031\001'
    _SETTRACETAG._options = None
    _SETTRACETAG._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _DELETETRACETAG.fields_by_name['trace_id']._options = None
    _DELETETRACETAG.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _DELETETRACETAG.fields_by_name['location_id']._options = None
    _DELETETRACETAG.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _DELETETRACETAG.fields_by_name['key']._options = None
    _DELETETRACETAG.fields_by_name['key']._serialized_options = b'\370\206\031\001'
    _DELETETRACETAG._options = None
    _DELETETRACETAG._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _SEARCHTRACES._options = None
    _SEARCHTRACES._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _CREATETRACEUCSTORAGELOCATION.fields_by_name['sql_warehouse_id']._options = None
    _CREATETRACEUCSTORAGELOCATION.fields_by_name['sql_warehouse_id']._serialized_options = b'\370\206\031\001'
    _CREATETRACEUCSTORAGELOCATION._options = None
    _CREATETRACEUCSTORAGELOCATION._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _LINKEXPERIMENTTOUCTRACELOCATION.fields_by_name['experiment_id']._options = None
    _LINKEXPERIMENTTOUCTRACELOCATION.fields_by_name['experiment_id']._serialized_options = b'\370\206\031\001'
    _LINKEXPERIMENTTOUCTRACELOCATION._options = None
    _LINKEXPERIMENTTOUCTRACELOCATION._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _UNLINKEXPERIMENTTOUCTRACELOCATION.fields_by_name['experiment_id']._options = None
    _UNLINKEXPERIMENTTOUCTRACELOCATION.fields_by_name['experiment_id']._serialized_options = b'\370\206\031\001'
    _UNLINKEXPERIMENTTOUCTRACELOCATION._options = None
    _UNLINKEXPERIMENTTOUCTRACELOCATION._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _ASSESSMENT_METADATAENTRY._options = None
    _ASSESSMENT_METADATAENTRY._serialized_options = b'8\001'
    _ASSESSMENT.fields_by_name['assessment_name']._options = None
    _ASSESSMENT.fields_by_name['assessment_name']._serialized_options = b'\370\206\031\001'
    _ASSESSMENT.fields_by_name['trace_id']._options = None
    _ASSESSMENT.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _CREATEASSESSMENT.fields_by_name['location_id']._options = None
    _CREATEASSESSMENT.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _CREATEASSESSMENT.fields_by_name['assessment']._options = None
    _CREATEASSESSMENT.fields_by_name['assessment']._serialized_options = b'\370\206\031\001'
    _CREATEASSESSMENT._options = None
    _CREATEASSESSMENT._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _GETASSESSMENT.fields_by_name['location_id']._options = None
    _GETASSESSMENT.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _GETASSESSMENT.fields_by_name['trace_id']._options = None
    _GETASSESSMENT.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _GETASSESSMENT.fields_by_name['assessment_id']._options = None
    _GETASSESSMENT.fields_by_name['assessment_id']._serialized_options = b'\370\206\031\001'
    _GETASSESSMENT._options = None
    _GETASSESSMENT._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _UPDATEASSESSMENT.fields_by_name['location_id']._options = None
    _UPDATEASSESSMENT.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _UPDATEASSESSMENT.fields_by_name['assessment']._options = None
    _UPDATEASSESSMENT.fields_by_name['assessment']._serialized_options = b'\370\206\031\001'
    _UPDATEASSESSMENT.fields_by_name['update_mask']._options = None
    _UPDATEASSESSMENT.fields_by_name['update_mask']._serialized_options = b'\370\206\031\001'
    _UPDATEASSESSMENT._options = None
    _UPDATEASSESSMENT._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _DELETEASSESSMENT.fields_by_name['location_id']._options = None
    _DELETEASSESSMENT.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _DELETEASSESSMENT.fields_by_name['trace_id']._options = None
    _DELETEASSESSMENT.fields_by_name['trace_id']._serialized_options = b'\370\206\031\001'
    _DELETEASSESSMENT.fields_by_name['assessment_id']._options = None
    _DELETEASSESSMENT.fields_by_name['assessment_id']._serialized_options = b'\370\206\031\001'
    _DELETEASSESSMENT._options = None
    _DELETEASSESSMENT._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _BATCHLINKTRACETORUN.fields_by_name['location_id']._options = None
    _BATCHLINKTRACETORUN.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _BATCHLINKTRACETORUN.fields_by_name['run_id']._options = None
    _BATCHLINKTRACETORUN.fields_by_name['run_id']._serialized_options = b'\370\206\031\001'
    _BATCHLINKTRACETORUN._options = None
    _BATCHLINKTRACETORUN._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _BATCHUNLINKTRACEFROMRUN.fields_by_name['location_id']._options = None
    _BATCHUNLINKTRACEFROMRUN.fields_by_name['location_id']._serialized_options = b'\370\206\031\001'
    _BATCHUNLINKTRACEFROMRUN.fields_by_name['run_id']._options = None
    _BATCHUNLINKTRACEFROMRUN.fields_by_name['run_id']._serialized_options = b'\370\206\031\001'
    _BATCHUNLINKTRACEFROMRUN._options = None
    _BATCHUNLINKTRACEFROMRUN._serialized_options = b'\342?(\n&com.databricks.rpc.RPC[$this.Response]'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['createTraceInfo']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['createTraceInfo']._serialized_options = b'\362\206\031_\nE\n\004POST\0227/mlflow/traces/{location_id}/{trace_info.trace_id}/info\032\004\010\004\020\000\020\003*\024Create Trace Info v4'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['batchGetTraces']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['batchGetTraces']._serialized_options = b'\362\206\031E\n2\n\003GET\022%/mlflow/traces/{location_id}/batchGet\032\004\010\004\020\000\020\003*\rGet Traces V4'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['getTraceInfo']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['getTraceInfo']._serialized_options = b'\362\206\031I\n6\n\003GET\022)/mlflow/traces/{location}/{trace_id}/info\032\004\010\004\020\000\020\003*\rGet TraceInfo'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['setTraceTag']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['setTraceTag']._serialized_options = b'\362\206\031N\n;\n\005PATCH\022,/mlflow/traces/{location_id}/{trace_id}/tags\032\004\010\004\020\000\020\003*\rSet Trace Tag'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['deleteTraceTag']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['deleteTraceTag']._serialized_options = b'\362\206\031X\nB\n\006DELETE\0222/mlflow/traces/{location_id}/{trace_id}/tags/{key}\032\004\010\004\020\000\020\003*\020Delete Trace Tag'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['searchTraces']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['searchTraces']._serialized_options = b'\362\206\0316\n#\n\004POST\022\025/mlflow/traces/search\032\004\010\004\020\000\020\003*\rSearch Traces'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['createTraceUCStorageLocation']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['createTraceUCStorageLocation']._serialized_options = b'\362\206\031K\n%\n\004POST\022\027/mlflow/traces/location\032\004\010\004\020\000\020\003* Create Trace UC Storage Location'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['linkExperimentToUCTraceLocation']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['linkExperimentToUCTraceLocation']._serialized_options = b'\362\206\031d\n:\n\004POST\022,/mlflow/traces/{experiment_id}/link-location\032\004\010\004\020\000\020\003*$Link Experiment to UC Trace Location'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['unlinkExperimentToUCTraceLocation']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['unlinkExperimentToUCTraceLocation']._serialized_options = b'\362\206\031h\n<\n\004POST\022./mlflow/traces/{experiment_id}/unlink-location\032\004\010\004\020\000\020\003*&Unlink Experiment to UC Trace Location'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['createAssessment']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['createAssessment']._serialized_options = b'\362\206\031c\nL\n\004POST\022>/mlflow/traces/{location_id}/{assessment.trace_id}/assessments\032\004\010\004\020\000\020\003*\021Create Assessment'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['getAssessment']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['getAssessment']._serialized_options = b'\362\206\031d\nP\n\003GET\022C/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\032\004\010\004\020\000\020\003*\016Get Assessment'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['updateAssessment']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['updateAssessment']._serialized_options = b'\362\206\031\177\nh\n\005PATCH\022Y/mlflow/traces/{location_id}/{assessment.trace_id}/assessments/{assessment.assessment_id}\032\004\010\004\020\000\020\003*\021Update Assessment'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['deleteAssessment']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['deleteAssessment']._serialized_options = b'\362\206\031j\nS\n\006DELETE\022C/mlflow/traces/{location_id}/{trace_id}/assessments/{assessment_id}\032\004\010\004\020\000\020\003*\021Delete Assessment'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['batchLinkTraceToRun']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['batchLinkTraceToRun']._serialized_options = b'\362\206\031Z\nB\n\004POST\0224/mlflow/traces/{location_id}/link-to-run/batchCreate\032\004\010\004\020\000\020\003*\022Link Traces to Run'
    _DATABRICKSTRACKINGSERVICE.methods_by_name['batchUnlinkTraceFromRun']._options = None
    _DATABRICKSTRACKINGSERVICE.methods_by_name['batchUnlinkTraceFromRun']._serialized_options = b'\362\206\031d\nH\n\006DELETE\0228/mlflow/traces/{location_id}/unlink-from-run/batchDelete\032\004\010\004\020\000\020\003*\026Unlink Traces from Run'
    _UCSCHEMALOCATION._serialized_start=248
    _UCSCHEMALOCATION._serialized_end=370
    _MLFLOWEXPERIMENTLOCATION._serialized_start=372
    _MLFLOWEXPERIMENTLOCATION._serialized_end=421
    _INFERENCETABLELOCATION._serialized_start=423
    _INFERENCETABLELOCATION._serialized_end=472
    _TRACELOCATION._serialized_start=475
    _TRACELOCATION._serialized_end=889
    _TRACELOCATION_TRACELOCATIONTYPE._serialized_start=760
    _TRACELOCATION_TRACELOCATIONTYPE._serialized_end=875
    _TRACEINFO._serialized_start=892
    _TRACEINFO._serialized_end=1559
    _TRACEINFO_TRACEMETADATAENTRY._serialized_start=1394
    _TRACEINFO_TRACEMETADATAENTRY._serialized_end=1446
    _TRACEINFO_TAGSENTRY._serialized_start=1448
    _TRACEINFO_TAGSENTRY._serialized_end=1491
    _TRACEINFO_STATE._serialized_start=1493
    _TRACEINFO_STATE._serialized_end=1559
    _CREATETRACEINFO._serialized_start=1562
    _CREATETRACEINFO._serialized_end=1769
    _CREATETRACEINFO_RESPONSE._serialized_start=1664
    _CREATETRACEINFO_RESPONSE._serialized_end=1724
    _TRACEPATH._serialized_start=1771
    _TRACEPATH._serialized_end=1870
    _TRACE._serialized_start=1872
    _TRACE._serialized_end=1980
    _BATCHGETTRACES._serialized_start=1983
    _BATCHGETTRACES._serialized_end=2170
    _BATCHGETTRACES_RESPONSE._serialized_start=2073
    _BATCHGETTRACES_RESPONSE._serialized_end=2125
    _GETTRACEINFO._serialized_start=2173
    _GETTRACEINFO._serialized_end=2359
    _GETTRACEINFO_RESPONSE._serialized_start=2263
    _GETTRACEINFO_RESPONSE._serialized_end=2314
    _SETTRACETAG._serialized_start=2362
    _SETTRACETAG._serialized_end=2517
    _SETTRACETAG_RESPONSE._serialized_start=1664
    _SETTRACETAG_RESPONSE._serialized_end=1674
    _DELETETRACETAG._serialized_start=2520
    _DELETETRACETAG._serialized_end=2689
    _DELETETRACETAG_RESPONSE._serialized_start=1664
    _DELETETRACETAG_RESPONSE._serialized_end=1674
    _SEARCHTRACES._serialized_start=2692
    _SEARCHTRACES._serialized_end=2998
    _SEARCHTRACES_RESPONSE._serialized_start=2867
    _SEARCHTRACES_RESPONSE._serialized_end=2953
    _CREATETRACEUCSTORAGELOCATION._serialized_start=3001
    _CREATETRACEUCSTORAGELOCATION._serialized_end=3246
    _CREATETRACEUCSTORAGELOCATION_RESPONSE._serialized_start=3123
    _CREATETRACEUCSTORAGELOCATION_RESPONSE._serialized_end=3189
    _LINKEXPERIMENTTOUCTRACELOCATION._serialized_start=3249
    _LINKEXPERIMENTTOUCTRACELOCATION._serialized_end=3438
    _LINKEXPERIMENTTOUCTRACELOCATION_RESPONSE._serialized_start=1664
    _LINKEXPERIMENTTOUCTRACELOCATION_RESPONSE._serialized_end=1674
    _UNLINKEXPERIMENTTOUCTRACELOCATION._serialized_start=3441
    _UNLINKEXPERIMENTTOUCTRACELOCATION._serialized_end=3632
    _UNLINKEXPERIMENTTOUCTRACELOCATION_RESPONSE._serialized_start=1664
    _UNLINKEXPERIMENTTOUCTRACELOCATION_RESPONSE._serialized_end=1674
    _ASSESSMENT._serialized_start=3635
    _ASSESSMENT._serialized_end=4243
    _ASSESSMENT_METADATAENTRY._serialized_start=4187
    _ASSESSMENT_METADATAENTRY._serialized_end=4234
    _CREATEASSESSMENT._serialized_start=4246
    _CREATEASSESSMENT._serialized_end=4482
    _CREATEASSESSMENT_RESPONSE._serialized_start=4376
    _CREATEASSESSMENT_RESPONSE._serialized_end=4437
    _GETASSESSMENT._serialized_start=4485
    _GETASSESSMENT._serialized_end=4714
    _GETASSESSMENT_RESPONSE._serialized_start=4376
    _GETASSESSMENT_RESPONSE._serialized_end=4437
    _UPDATEASSESSMENT._serialized_start=4717
    _UPDATEASSESSMENT._serialized_end=5008
    _UPDATEASSESSMENT_RESPONSE._serialized_start=4376
    _UPDATEASSESSMENT_RESPONSE._serialized_end=4437
    _DELETEASSESSMENT._serialized_start=5011
    _DELETEASSESSMENT._serialized_end=5192
    _DELETEASSESSMENT_RESPONSE._serialized_start=1664
    _DELETEASSESSMENT_RESPONSE._serialized_end=1674
    _BATCHLINKTRACETORUN._serialized_start=5195
    _BATCHLINKTRACETORUN._serialized_end=5341
    _BATCHLINKTRACETORUN_RESPONSE._serialized_start=1664
    _BATCHLINKTRACETORUN_RESPONSE._serialized_end=1674
    _BATCHUNLINKTRACEFROMRUN._serialized_start=5344
    _BATCHUNLINKTRACEFROMRUN._serialized_end=5494
    _BATCHUNLINKTRACEFROMRUN_RESPONSE._serialized_start=1664
    _BATCHUNLINKTRACEFROMRUN_RESPONSE._serialized_end=1674
    _DATABRICKSTRACKINGSERVICE._serialized_start=5497
    _DATABRICKSTRACKINGSERVICE._serialized_end=8617
  DatabricksTrackingService = service_reflection.GeneratedServiceType('DatabricksTrackingService', (_service.Service,), dict(
    DESCRIPTOR = _DATABRICKSTRACKINGSERVICE,
    __module__ = 'databricks_tracing_pb2'
    ))

  DatabricksTrackingService_Stub = service_reflection.GeneratedServiceStubType('DatabricksTrackingService_Stub', (DatabricksTrackingService,), dict(
    DESCRIPTOR = _DATABRICKSTRACKINGSERVICE,
    __module__ = 'databricks_tracing_pb2'
    ))


  # @@protoc_insertion_point(module_scope)




from dataclasses import dataclass, field

from mlflow.models import ModelSignature
from mlflow.types.schema import (
    Array,
    ColSpec,
    DataType,
    Object,
    Property,
    Schema,
)
from mlflow.utils.annotations import deprecated


@deprecated("mlflow.types.llm.ChatMessage")
@dataclass
class Message:
    role: str = "user"  # "system", "user", or "assistant"
    content: str = "What is mlflow?"


@deprecated("mlflow.types.llm.ChatCompletionRequest")
@dataclass
class ChatCompletionRequest:
    messages: list[Message] = field(default_factory=lambda: [Message()])


@deprecated("mlflow.types.llm.ChatCompletionRequest")
@dataclass
class SplitChatMessagesRequest:
    query: str = "What is mlflow?"
    history: list[Message] | None = field(default_factory=list)


@deprecated("mlflow.types.llm.ChatCompletionRequest")
@dataclass
class MultiturnChatRequest:
    query: str = "What is mlflow?"
    history: list[Message] | None = field(default_factory=list)


@deprecated("mlflow.types.llm.ChatChoice")
@dataclass
class ChainCompletionChoice:
    index: int = 0
    message: Message = field(
        default_factory=lambda: Message(
            role="assistant",
            content="MLflow is an open source platform for the machine learning lifecycle.",
        )
    )
    finish_reason: str = "stop"


@deprecated("mlflow.types.llm.ChatCompletionChunk")
@dataclass
class ChainCompletionChunk:
    index: int = 0
    delta: Message = field(
        default_factory=lambda: Message(
            role="assistant",
            content="MLflow is an open source platform for the machine learning lifecycle.",
        )
    )
    finish_reason: str = "stop"


@deprecated("mlflow.types.llm.ChatCompletionResponse")
@dataclass
class ChatCompletionResponse:
    choices: list[ChainCompletionChoice] = field(default_factory=lambda: [ChainCompletionChoice()])
    object: str = "chat.completion"
    # TODO: support ChainCompletionChunk in the future


@deprecated("mlflow.types.llm.ChatCompletionResponse")
@dataclass
class StringResponse:
    content: str = "MLflow is an open source platform for the machine learning lifecycle."


CHAT_COMPLETION_REQUEST_SCHEMA = Schema(
    [
        ColSpec(
            name="messages",
            type=Array(
                Object(
                    [
                        Property("role", DataType.string),
                        Property("content", DataType.string),
                    ]
                )
            ),
        ),
    ]
)

CHAT_COMPLETION_RESPONSE_SCHEMA = Schema(
    [
        ColSpec(
            name="choices",
            type=Array(
                Object(
                    [
                        Property("index", DataType.long),
                        Property(
                            "message",
                            Object(
                                [
                                    Property("role", DataType.string),
                                    Property("content", DataType.string),
                                ]
                            ),
                        ),
                        Property("finish_reason", DataType.string),
                    ]
                )
            ),
        ),
    ]
)

SIGNATURE_FOR_LLM_INFERENCE_TASK = {
    "llm/v1/chat": ModelSignature(
        inputs=CHAT_COMPLETION_REQUEST_SCHEMA, outputs=CHAT_COMPLETION_RESPONSE_SCHEMA
    ),
}



import contextlib
import json
import logging
import os
import shutil
import sys
from pathlib import Path
from typing import Any

import yaml

from mlflow.exceptions import MlflowException
from mlflow.models import Model
from mlflow.models.model import MLMODEL_FILE_NAME
from mlflow.protos.databricks_pb2 import (
    INVALID_PARAMETER_VALUE,
    RESOURCE_ALREADY_EXISTS,
    RESOURCE_DOES_NOT_EXIST,
)
from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
from mlflow.store.artifact.models_artifact_repo import ModelsArtifactRepository
from mlflow.store.artifact.runs_artifact_repo import RunsArtifactRepository
from mlflow.tracking.artifact_utils import _download_artifact_from_uri
from mlflow.utils import get_parent_module
from mlflow.utils.databricks_utils import is_in_databricks_runtime
from mlflow.utils.file_utils import _copy_file_or_tree
from mlflow.utils.requirements_utils import _capture_imported_modules
from mlflow.utils.uri import append_to_uri_path

FLAVOR_CONFIG_CODE = "code"

_logger = logging.getLogger(__name__)


def _get_all_flavor_configurations(model_path):
    """Obtains all the flavor configurations from the specified MLflow model path.

    Args:
        model_path: The path to the root directory of the MLflow model for which to load
            the specified flavor configuration.

    Returns:
        The dictionary contains all flavor configurations with flavor name as key.

    """

    return Model.load(model_path).flavors


def _get_flavor_configuration(model_path, flavor_name):
    """Obtains the configuration for the specified flavor from the specified
    MLflow model path. If the model does not contain the specified flavor,
    an exception will be thrown.

    Args:
        model_path: The path to the root directory of the MLflow model for which to load
            the specified flavor configuration.
        flavor_name: The name of the flavor configuration to load.

    Returns:
        The flavor configuration as a dictionary.

    """
    try:
        return Model.load(model_path).flavors[flavor_name]
    except KeyError as ex:
        raise MlflowException(
            f'Model does not have the "{flavor_name}" flavor', RESOURCE_DOES_NOT_EXIST
        ) from ex


def _get_flavor_configuration_from_uri(model_uri, flavor_name, logger):
    """Obtains the configuration for the specified flavor from the specified
    MLflow model uri. If the model does not contain the specified flavor,
    an exception will be thrown.

    Args:
        model_uri: The path to the root directory of the MLflow model for which to load
            the specified flavor configuration.
        flavor_name: The name of the flavor configuration to load.
        logger: The local flavor's logger to report the resolved path of the model uri.

    Returns:
        The flavor configuration as a dictionary.
    """
    try:
        resolved_uri = model_uri
        if RunsArtifactRepository.is_runs_uri(model_uri):
            resolved_uri = RunsArtifactRepository.get_underlying_uri(model_uri)
            logger.info("'%s' resolved as '%s'", model_uri, resolved_uri)
        elif ModelsArtifactRepository.is_models_uri(model_uri):
            resolved_uri = ModelsArtifactRepository.get_underlying_uri(model_uri)
            logger.info("'%s' resolved as '%s'", model_uri, resolved_uri)

        try:
            ml_model_file = _download_artifact_from_uri(
                artifact_uri=append_to_uri_path(resolved_uri, MLMODEL_FILE_NAME)
            )
        except Exception:
            logger.debug(
                f'Failed to download an "{MLMODEL_FILE_NAME}" model file from '
                f"resolved URI {resolved_uri}. "
                f"Falling back to downloading from original model URI {model_uri}",
                exc_info=True,
            )
            ml_model_file = get_artifact_repository(artifact_uri=model_uri).download_artifacts(
                artifact_path=MLMODEL_FILE_NAME
            )
    except Exception as ex:
        raise MlflowException(
            f'Failed to download an "{MLMODEL_FILE_NAME}" model file from "{model_uri}"',
            RESOURCE_DOES_NOT_EXIST,
        ) from ex
    return _get_flavor_configuration_from_ml_model_file(ml_model_file, flavor_name)


def _get_flavor_configuration_from_ml_model_file(ml_model_file, flavor_name):
    model_conf = Model.load(ml_model_file)
    if flavor_name not in model_conf.flavors:
        raise MlflowException(
            f'Model does not have the "{flavor_name}" flavor',
            RESOURCE_DOES_NOT_EXIST,
        )
    return model_conf.flavors[flavor_name]


def _validate_code_paths(code_paths):
    if code_paths is not None:
        if not isinstance(code_paths, list):
            raise TypeError(f"Argument code_paths should be a list, not {type(code_paths)}")


def _validate_and_copy_code_paths(code_paths, path, default_subpath="code"):
    """Validates that a code path is a valid list and copies the code paths to a directory. This
    can later be used to log custom code as an artifact.

    Args:
        code_paths: A list of files or directories containing code that should be logged
            as artifacts.
        path: The local model path.
        default_subpath: The default directory name used to store code artifacts.
    """
    _validate_code_paths(code_paths)
    if code_paths is not None:
        code_dir_subpath = default_subpath
        for code_path in code_paths:
            try:
                _copy_file_or_tree(src=code_path, dst=path, dst_dir=code_dir_subpath)
            except OSError as e:
                # A common error is code-paths includes Databricks Notebook. We include it in error
                # message when running in Databricks, but not in other envs tp avoid confusion.
                example = ", such as Databricks Notebooks" if is_in_databricks_runtime() else ""
                raise MlflowException(
                    message=(
                        f"Failed to copy the specified code path '{code_path}' into the model "
                        "artifacts. It appears that your code path includes file(s) that cannot "
                        f"be copied{example}. Please specify a code path that does not include "
                        "such files and try again.",
                    ),
                    error_code=INVALID_PARAMETER_VALUE,
                ) from e
    else:
        code_dir_subpath = None
    return code_dir_subpath


def _infer_and_copy_code_paths(flavor, path, default_subpath="code"):
    # Capture all imported modules with full module name during loading model.
    modules = _capture_imported_modules(path, flavor, record_full_module=True)

    all_modules = set(modules)

    for module in modules:
        parent_module = module
        while "." in parent_module:
            parent_module = get_parent_module(parent_module)
            all_modules.add(parent_module)

    # Generate code_paths set from the imported modules full name list.
    # It only picks necessary files, because:
    #  1. Reduce risk of logging files containing user credentials to MLflow
    #     artifact repository.
    #  2. In databricks runtime, notebook files might exist under a code_paths directory,
    #     if logging the whole directory to MLflow artifact repository, these
    #     notebook files are not accessible and trigger exceptions. On the other
    #     hand, these notebook files are not used as code_paths modules because
    #     code in notebook files are loaded into python `__main__` module.
    code_paths = set()
    for full_module_name in all_modules:
        relative_path_str = full_module_name.replace(".", os.sep)
        relative_path = Path(relative_path_str)
        if relative_path.is_dir():
            init_file_path = relative_path / "__init__.py"
            if init_file_path.exists():
                code_paths.add(init_file_path)

        py_module_path = Path(relative_path_str + ".py")
        if py_module_path.is_file():
            code_paths.add(py_module_path)

    if code_paths:
        for code_path in code_paths:
            src_dir_path = code_path.parent
            src_file_name = code_path.name
            dest_dir_path = Path(path) / default_subpath / src_dir_path
            dest_file_path = dest_dir_path / src_file_name
            dest_dir_path.mkdir(parents=True, exist_ok=True)
            shutil.copyfile(code_path, dest_file_path)
        return default_subpath

    return None


def _validate_infer_and_copy_code_paths(
    code_paths, path, infer_code_paths, flavor, default_subpath="code"
):
    if infer_code_paths:
        if code_paths:
            raise MlflowException(
                "If 'infer_code_path' is set to True, 'code_paths' param cannot be set."
            )
        return _infer_and_copy_code_paths(flavor, path, default_subpath)
    else:
        return _validate_and_copy_code_paths(code_paths, path, default_subpath)


def _validate_path_exists(path, name):
    if path and not os.path.exists(path):
        raise MlflowException(
            message=(
                f"Failed to copy the specified {name} path '{path}' into the model "
                f"artifacts. The specified {name}path does not exist. Please specify a valid "
                f"{name} path and try again."
            ),
            error_code=INVALID_PARAMETER_VALUE,
        )


def _validate_and_copy_file_to_directory(file_path: str, dir_path: str, name: str):
    """Copies the file at file_path to the directory at dir_path.

    Args:
        file_path: A file that should be logged as an artifact.
        dir_path: The path of the directory to save the file to.
        name: The name for the kind of file being copied.
    """
    _validate_path_exists(file_path, name)
    try:
        _copy_file_or_tree(src=file_path, dst=dir_path)
    except OSError as e:
        # A common error is code-paths includes Databricks Notebook. We include it in error
        # message when running in Databricks, but not in other envs tp avoid confusion.
        example = ", such as Databricks Notebooks" if is_in_databricks_runtime() else ""
        raise MlflowException(
            message=(
                f"Failed to copy the specified code path '{file_path}' into the model "
                "artifacts. It appears that your code path includes file(s) that cannot "
                f"be copied{example}. Please specify a code path that does not include "
                "such files and try again.",
            ),
            error_code=INVALID_PARAMETER_VALUE,
        ) from e


def _add_code_to_system_path(code_path):
    sys.path = [code_path] + sys.path


def _validate_and_prepare_target_save_path(path):
    if os.path.exists(path) and any(os.scandir(path)):
        raise MlflowException(
            message=f"Path '{path}' already exists and is not empty",
            error_code=RESOURCE_ALREADY_EXISTS,
        )

    os.makedirs(path, exist_ok=True)


def _add_code_from_conf_to_system_path(local_path, conf, code_key=FLAVOR_CONFIG_CODE):
    """Checks if any code_paths were logged with the model in the flavor conf and prepends
    the directory to the system path.

    Args:
        local_path: The local path containing model artifacts.
        conf: The flavor-specific conf that should contain the FLAVOR_CONFIG_CODE
            key, which specifies the directory containing custom code logged as artifacts.
        code_key: The key used by the flavor to indicate custom code artifacts.
            By default this is FLAVOR_CONFIG_CODE.
    """
    assert isinstance(conf, dict), "`conf` argument must be a dict."

    if code_key in conf and conf[code_key]:
        code_path = os.path.join(local_path, conf[code_key])
        _add_code_to_system_path(code_path)


def _validate_onnx_session_options(onnx_session_options):
    """Validates that the specified onnx_session_options dict is valid.

    Args:
        onnx_session_options: The onnx_session_options dict to validate.
    """
    import onnxruntime as ort

    if onnx_session_options is not None:
        if not isinstance(onnx_session_options, dict):
            raise TypeError(
                f"Argument onnx_session_options should be a dict, not {type(onnx_session_options)}"
            )
        for key, value in onnx_session_options.items():
            if key != "extra_session_config" and not hasattr(ort.SessionOptions, key):
                raise ValueError(
                    f"Key {key} in onnx_session_options is not a valid "
                    "ONNX Runtime session options key"
                )
            elif key == "extra_session_config" and not isinstance(value, dict):
                raise TypeError(
                    f"Value for key {key} in onnx_session_options should be a dict, "
                    "not {type(value)}"
                )
            elif key == "execution_mode" and value.upper() not in [
                "PARALLEL",
                "SEQUENTIAL",
            ]:
                raise ValueError(
                    f"Value for key {key} in onnx_session_options should be "
                    f"'parallel' or 'sequential', not {value}"
                )
            elif key == "graph_optimization_level" and value not in [0, 1, 2, 99]:
                raise ValueError(
                    f"Value for key {key} in onnx_session_options should be 0, 1, 2, or 99, "
                    f"not {value}"
                )
            elif key in ["intra_op_num_threads", "intra_op_num_threads"] and value < 0:
                raise ValueError(
                    f"Value for key {key} in onnx_session_options should be >= 0, not {value}"
                )


def _get_overridden_pyfunc_model_config(
    pyfunc_config: dict[str, Any], load_config: dict[str, Any], logger
) -> dict[str, Any]:
    """
    Updates the inference configuration according to the model's configuration and the overrides.
    Only arguments already present in the inference configuration can be updated. The environment
    variable ``MLFLOW_PYFUNC_INFERENCE_CONFIG`` can also be used to provide additional inference
    configuration.
    """

    overrides = {}
    if env_overrides := os.getenv("MLFLOW_PYFUNC_INFERENCE_CONFIG"):
        logger.debug(
            "Inference configuration is being loaded from ``MLFLOW_PYFUNC_INFERENCE_CONFIG``"
            " environ."
        )
        overrides.update(dict(json.loads(env_overrides)))

    if load_config:
        overrides.update(load_config)

    if not overrides:
        return pyfunc_config

    if not pyfunc_config:
        logger.warning(
            f"Argument(s) {', '.join(overrides.keys())} were ignored since the model's ``pyfunc``"
            " flavor doesn't accept model configuration. Use ``model_config`` when logging"
            " the model to allow it."
        )

        return None

    valid_keys = set(pyfunc_config.keys()) & set(overrides.keys())
    ignored_keys = set(overrides.keys()) - valid_keys
    allowed_config = {key: overrides[key] for key in valid_keys}
    if ignored_keys:
        logger.warning(
            f"Argument(s) {', '.join(ignored_keys)} were ignored since they are not valid keys in"
            " the corresponding section of the ``pyfunc`` flavor. Use ``model_config`` when"
            " logging the model to include the keys you plan to indicate. Current allowed"
            f" configuration includes {', '.join(pyfunc_config.keys())}"
        )
    pyfunc_config.update(allowed_config)
    return pyfunc_config


def _validate_and_get_model_config_from_file(model_config):
    model_config = os.path.abspath(model_config)
    if os.path.exists(model_config):
        with open(model_config) as file:
            try:
                return yaml.safe_load(file)
            except yaml.YAMLError as e:
                raise MlflowException(
                    f"The provided `model_config` file '{model_config}' is not a valid YAML "
                    f"file: {e}",
                    error_code=INVALID_PARAMETER_VALUE,
                )
    else:
        raise MlflowException(
            "An invalid `model_config` file was passed. The provided `model_config` "
            f"file '{model_config}'is not a valid file path.",
            error_code=INVALID_PARAMETER_VALUE,
        )


def _validate_pyfunc_model_config(model_config):
    """
    Validates the values passes in the model_config section. There are no typing
    restrictions but we require them being JSON-serializable.
    """

    if not model_config:
        return

    if isinstance(model_config, Path):
        _validate_and_get_model_config_from_file(os.fspath(model_config))
    elif isinstance(model_config, str):
        _validate_and_get_model_config_from_file(model_config)
    elif isinstance(model_config, dict) and all(isinstance(key, str) for key in model_config):
        try:
            json.dumps(model_config)
        except (TypeError, OverflowError):
            raise MlflowException(
                "Values in the provided ``model_config`` are of an unsupported type. Only "
                "JSON-serializable data types can be provided as values.",
                error_code=INVALID_PARAMETER_VALUE,
            )
    else:
        raise MlflowException(
            "An invalid ``model_config`` structure was passed. ``model_config`` must be a "
            "valid file path or of type ``dict`` with string keys.",
            error_code=INVALID_PARAMETER_VALUE,
        )


RECORD_ENV_VAR_ALLOWLIST = {
    # api key related
    "API_KEY",
    "API_TOKEN",
    # databricks auth related
    "DATABRICKS_HOST",
    "DATABRICKS_USERNAME",
    "DATABRICKS_PASSWORD",
    "DATABRICKS_TOKEN",
    "DATABRICKS_INSECURE",
    "DATABRICKS_CLIENT_ID",
    "DATABRICKS_CLIENT_SECRET",
    "_DATABRICKS_WORKSPACE_HOST",
    "_DATABRICKS_WORKSPACE_ID",
}


@contextlib.contextmanager
def env_var_tracker():
    """
    Context manager for temporarily tracking environment variables accessed.
    It tracks environment variables accessed during the context manager's lifetime.
    """
    from mlflow.environment_variables import MLFLOW_RECORD_ENV_VARS_IN_MODEL_LOGGING

    tracked_env_names = set()

    if MLFLOW_RECORD_ENV_VARS_IN_MODEL_LOGGING.get():
        original_getitem = os._Environ.__getitem__
        original_get = os._Environ.get

        def updated_get_item(self, key):
            result = original_getitem(self, key)
            tracked_env_names.add(key)
            return result

        def updated_get(self, key, *args, **kwargs):
            if key in self:
                tracked_env_names.add(key)
            return original_get(self, key, *args, **kwargs)

        try:
            os._Environ.__getitem__ = updated_get_item
            os._Environ.get = updated_get
            yield tracked_env_names
        finally:
            os._Environ.__getitem__ = original_getitem
            os._Environ.get = original_get
    else:
        yield tracked_env_names



from typing import TYPE_CHECKING, Any, Iterable, Union

from mlflow.entities import Trace
from mlflow.exceptions import MlflowException
from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE

if TYPE_CHECKING:
    import pandas as pd
    from databricks.agents.review_app import (
        LabelSchema as _LabelSchema,
    )
    from databricks.agents.review_app import (
        ReviewApp as _ReviewApp,
    )
    from databricks.agents.review_app.labeling import Agent as _Agent


class Agent:
    """The agent configuration, used for generating responses in the review app.

    .. note::
        This functionality is only available in Databricks. Please run
        `pip install mlflow[databricks]` to use it.
    """

    def __init__(self, agent: "_Agent"):
        self._agent = agent

    @property
    def agent_name(self) -> str:
        """The name of the agent."""
        return self._agent.agent_name

    @property
    def model_serving_endpoint(self) -> str:
        """The model serving endpoint used by the agent."""
        return self._agent.model_serving_endpoint


class LabelingSession:
    """A session for labeling items in the review app.

    .. note::
        This functionality is only available in Databricks. Please run
        `pip install mlflow[databricks]` to use it.
    """

    def __init__(
        self,
        *,
        name: str,
        assigned_users: list[str],
        agent: str | None,
        label_schemas: list[str],
        labeling_session_id: str,
        mlflow_run_id: str,
        review_app_id: str,
        experiment_id: str,
        url: str,
        enable_multi_turn_chat: bool,
        custom_inputs: dict[str, Any] | None,
    ):
        self._name = name
        self._assigned_users = assigned_users
        self._agent = agent
        self._label_schemas = label_schemas
        self._labeling_session_id = labeling_session_id
        self._mlflow_run_id = mlflow_run_id
        self._review_app_id = review_app_id
        self._experiment_id = experiment_id
        self._url = url
        self._enable_multi_turn_chat = enable_multi_turn_chat
        self._custom_inputs = custom_inputs

    @property
    def name(self) -> str:
        """The name of the labeling session."""
        return self._name

    @property
    def assigned_users(self) -> list[str]:
        """The users assigned to label items in the session."""
        return self._assigned_users

    @property
    def agent(self) -> str | None:
        """The agent used to generate responses for the items in the session."""
        return self._agent

    @property
    def label_schemas(self) -> list[str]:
        """The label schemas used in the session."""
        return self._label_schemas

    @property
    def labeling_session_id(self) -> str:
        """The unique identifier of the labeling session."""
        return self._labeling_session_id

    @property
    def mlflow_run_id(self) -> str:
        """The MLflow run ID associated with the session."""
        return self._mlflow_run_id

    @property
    def review_app_id(self) -> str:
        """The review app ID associated with the session."""
        return self._review_app_id

    @property
    def experiment_id(self) -> str:
        """The experiment ID associated with the session."""
        return self._experiment_id

    @property
    def url(self) -> str:
        """The URL of the labeling session in the review app."""
        return self._url

    @property
    def enable_multi_turn_chat(self) -> bool:
        """Whether multi-turn chat is enabled for the session."""
        return self._enable_multi_turn_chat

    @property
    def custom_inputs(self) -> dict[str, Any] | None:
        """Custom inputs used in the session."""
        return self._custom_inputs

    def _get_store(self):
        """
        Get a labeling store instance.

        This method is defined in order to avoid circular imports.
        """
        from mlflow.genai.labeling.stores import _get_labeling_store

        return _get_labeling_store()

    def add_dataset(
        self, dataset_name: str, record_ids: list[str] | None = None
    ) -> "LabelingSession":
        """Add a dataset to the labeling session.

        .. note::
            This functionality is only available in Databricks. Please run
            `pip install mlflow[databricks]` to use it.

        Args:
            dataset_name: The name of the dataset.
            record_ids: Optional. The individual record ids to be added to the session. If not
                provided, all records in the dataset will be added.

        Returns:
            LabelingSession: The updated labeling session.
        """
        store = self._get_store()
        return store.add_dataset_to_session(self, dataset_name, record_ids)

    def add_traces(
        self,
        traces: Union[Iterable[Trace], Iterable[str], "pd.DataFrame"],
    ) -> "LabelingSession":
        """Add traces to the labeling session.

        .. note::
            This functionality is only available in Databricks. Please run
            `pip install mlflow[databricks]` to use it.

        Args:
            traces: Can be either:
                a) a pandas DataFrame with a 'trace' column. The 'trace' column should contain
                either `mlflow.entities.Trace` objects or their json string representations.
                b) an iterable of `mlflow.entities.Trace` objects.
                c) an iterable of json string representations of `mlflow.entities.Trace` objects.

        Returns:
            LabelingSession: The updated labeling session.
        """
        import pandas as pd

        if isinstance(traces, pd.DataFrame):
            if "trace" not in traces.columns:
                raise MlflowException(
                    "traces must have a 'trace' column like the result of mlflow.search_traces()",
                    error_code=INVALID_PARAMETER_VALUE,
                )
            traces = traces["trace"].to_list()

        trace_list: list[Trace] = []
        for trace in traces:
            if isinstance(trace, str):
                trace_list.append(Trace.from_json(trace))
            elif isinstance(trace, Trace):
                trace_list.append(trace)
            elif trace is None:
                raise MlflowException(
                    "trace cannot be None. Must be mlflow.entities.Trace or its json string "
                    "representation.",
                    error_code=INVALID_PARAMETER_VALUE,
                )
            else:
                raise MlflowException(
                    f"Expected mlflow.entities.Trace or json string, got {type(trace).__name__}",
                    error_code=INVALID_PARAMETER_VALUE,
                )

        store = self._get_store()
        return store.add_traces_to_session(self, trace_list)

    def sync(self, to_dataset: str) -> None:
        """Sync the traces and expectations from the labeling session to a dataset.

        .. note::
            This functionality is only available in Databricks. Please run
            `pip install mlflow[databricks]` to use it.

        Args:
            to_dataset: The name of the dataset to sync traces and expectations to.
        """
        store = self._get_store()
        return store.sync_session_expectations(self, to_dataset)

    def set_assigned_users(self, assigned_users: list[str]) -> "LabelingSession":
        """Set the assigned users for the labeling session.

        .. note::
            This functionality is only available in Databricks. Please run
            `pip install mlflow[databricks]` to use it.

        Args:
            assigned_users: The list of users to assign to the session.

        Returns:
            LabelingSession: The updated labeling session.
        """
        store = self._get_store()
        return store.set_session_assigned_users(self, assigned_users)


class ReviewApp:
    """A review app is used to collect feedback from stakeholders for a given experiment.

    .. note::
        This functionality is only available in Databricks. Please run
        `pip install mlflow[databricks]` to use it.
    """

    def __init__(self, app: "_ReviewApp"):
        self._app = app

    @property
    def review_app_id(self) -> str:
        """The ID of the review app."""
        return self._app.review_app_id

    @property
    def experiment_id(self) -> str:
        """The ID of the experiment."""
        return self._app.experiment_id

    @property
    def url(self) -> str:
        """The URL of the review app for stakeholders to provide feedback."""
        return self._app.url

    @property
    def agents(self) -> list[Agent]:
        """The agents to be used to generate responses."""
        return [Agent(agent) for agent in self._app.agents]

    @property
    def label_schemas(self) -> list["_LabelSchema"]:
        """The label schemas to be used in the review app."""
        return self._app.label_schemas

    def add_agent(
        self, *, agent_name: str, model_serving_endpoint: str, overwrite: bool = False
    ) -> "ReviewApp":
        """Add an agent to the review app to be used to generate responses.

        .. note::
            This functionality is only available in Databricks. Please run
            `pip install mlflow[databricks]` to use it.

        Args:
            agent_name: The name of the agent.
            model_serving_endpoint: The model serving endpoint to be used by the agent.
            overwrite: Whether to overwrite an existing agent with the same name.

        Returns:
            ReviewApp: The updated review app.
        """
        return ReviewApp(
            self._app.add_agent(
                agent_name=agent_name,
                model_serving_endpoint=model_serving_endpoint,
                overwrite=overwrite,
            )
        )

    def remove_agent(self, agent_name: str) -> "ReviewApp":
        """Remove an agent from the review app.

        .. note::
            This functionality is only available in Databricks. Please run
            `pip install mlflow[databricks]` to use it.

        Args:
            agent_name: The name of the agent to remove.

        Returns:
            ReviewApp: The updated review app.
        """
        return ReviewApp(self._app.remove_agent(agent_name))



from mlflow.telemetry.events import AutologgingEvent
from mlflow.telemetry.track import _record_event
from mlflow.utils.autologging_utils import autologging_integration

FLAVOR_NAME = "ag2"


def autolog(
    log_traces: bool = True,
    disable: bool = False,
    silent: bool = False,
):
    """
    Enables (or disables) and configures autologging from ag2 to MLflow. Currently, MLflow
    only supports tracing for ag2 agents.

    Args:
        log_traces: If ``True``, traces are logged for AG2 agents by using runtime logging.
            If ``False``, no traces are collected during inference. Default to ``True``.
        disable: If ``True``, disables the AG2 autologging. Default to ``False``.
        silent: If ``True``, suppress all event logs and warnings from MLflow during AG2
            autologging. If ``False``, show all events and warnings.
    """
    from autogen import runtime_logging

    from mlflow.ag2.ag2_logger import MlflowAg2Logger

    # NB: The @autologging_integration annotation is used for adding shared logic. However, one
    # caveat is that the wrapped function is NOT executed when disable=True is passed. This prevents
    # us from running cleaning up logging when autologging is turned off. To workaround this, we
    # annotate _autolog() instead of this entrypoint, and define the cleanup logic outside it.
    # TODO: since this implementation is inconsistent, explore a universal way to solve the issue.
    if log_traces and not disable:
        runtime_logging.start(logger=MlflowAg2Logger())
    else:
        runtime_logging.stop()

    _autolog(log_traces=log_traces, disable=disable, silent=silent)


# This is required by mlflow.autolog()
autolog.integration_name = FLAVOR_NAME


@autologging_integration(FLAVOR_NAME)
def _autolog(
    log_traces: bool = True,
    disable: bool = False,
    silent: bool = False,
):
    """
    This is a dummy function only for the purpose of adding the autologging_integration annotation.
    We cannot add the annotation directly to the autolog() function above due to the reason
    mentioned in the comment above. Note that this function MUST declare the same signature as the
    autolog(), otherwise the annotation will not work properly.
    """
    _record_event(
        AutologgingEvent, {"flavor": FLAVOR_NAME, "log_traces": log_traces, "disable": disable}
    )



"""
This module defines developer APIs for defining pluggable execution backends
for MLflow projects. See `MLflow Plugins <../../plugins.html>`_ for more information.
"""

from mlflow.projects.backend.abstract_backend import AbstractBackend

__all__ = ["AbstractBackend"]
